# Full documentation

The full documentation for `rp-cli` (installation, configuration, use, etc.) is available on the [redpesk documentation website](http://redpesk-doc-internal.lorient.iot/docs/en/master/redpesk-factory/rp_cli/0_introduction.html).


# Development set-up

In order to make the development of `rp-cli` easier, few steps are needed, one of the first thing to do is to create a symbolic link.
This allows to always use your rp-cli freshly built!

```bash
$ ln -s /path/to/git/repo/redpesk-cli/bin/rp-cli /usr/local/bin/rp-cli
```

Then, if you want to take advantage of the completion you have two choices: 

* Either you run the following command at each terminal session: `source <(rp-cli completion bash)`
* Or you run once the following command: `rp-cli completion bash > /etc/bash_completion.d/rp-cli-prompt`

For the second option, you need to have the package `bash-completion` installed on your distribution.

# Building

This is very simple!
Go to your git repository named `redpesk-cli`, and run:

```bash
$ make build
### Build rp-cli (version 3.4.0, subversion 11-g72d7910 - Build mode: development)
```

The binary will be in `./bin/rp-cli`.

# Debugging

## Delve

We will use the `dlv` binary, coming from the "Delve" project to debug `redpesk-cli`. So, the first step is to install this binary in your working environment.

```bash
$ go get github.com/go-delve/delve/cmd/dlv
```

**N.B.**: Check that the repository where the binary is installed is listed in your `$PATH`.

## Debugging process

In order to debug `rp-cli`, you need to first run in the terminal the "delve" tools with the rp-cli subcommand you want to debug.
Let's take an example. Let's say you want to debug the `rp-cli applications list` command. The command line you need to launch is:

```bash
$ dlv debug --headless --listen=:2345 --log --api-version=2 -- applications list
API server listening at: [::]:2345
2022-01-27T13:13:44Z info layer=debugger launching process with args: [/home/devel/redpesk-cli/__debug_bin applications list]
```

Once the dlv server is running, you can go in the "debug" section of vscode, choose the "Remote dev" profile and click on "play". The debug process will start as usual.

**N.B.**: in the `.vscode/launch.json` file in `configurations`, check that the `"host"` value of the "Remote dev" match your IP address or the LXC container IP address where you are developing.

## Debugging the completion functions

If you start playing with completion, you will need for sure to debug it at some point.
In order to do that, simply use the `__complete` prefix in front of your command.

For example, let's say you want to debug the completion on the application name for the `rp-cli applications get ""`, you will have to write the following command line:

```bash
$ dlv debug --headless --listen=:2345 --log --api-version=2 -- __complete applications get ""
```

If you want to simulate that the user has started to write the name of an application, simply pass the first letter between the quotes. If it is an 'h', the command line is:

```bash
$ dlv debug --headless --listen=:2345 --log --api-version=2 -- __complete applications get "h"
```

### Common issues

If you get "EOF" error after clicking on play button in the vscode debugger:

- go to ~/.redpesk/rp-cli/cookies folder
- check the name of your rp-cli connection with:
  ``` bash
  $ rpcli connections current
  ```
- delete the file which starts with the "Alias value" of your rp-cli connection

# Testing

## Unit tests

In order to run the unit tests, with a mocked backend, simply run the following command line at the root of the project.

```bash
make test
```

## Testing with a real backend

It is now possible to run the `rp-cli` tests with a true backend. It allows to test that `rp-cli` is working with a real backend but also, it allows to validate a backend.
In order to do all of that, it is necessary to follow these few steps.

* Get your backend ready (run the following commands at the root of your `rp-webserver` project)

```bash
# Delete the database
make db

# Start the backend
make devb debug=1
```

* Create an access token for rp-cli through the webUI (cf. [configuration doc](http://redpesk-doc-internal.lorient.iot/docs/en/master/redpesk-factory/rp_cli/2_configuration.html#redpesk-infrastructure-access)), copy it and save it somewhere

* Change the access token used for rp-cli inside the file named `access_token.json` in the directory `~/.redpesk/rp-cli/`. In this file set the token previously copied. You can also use the `rp-cli onboard` command in order to do that

* Stop your backend, and restart it (in the other case, it seems that the backend crashes randomly during the tests)

```bash
^C

# Restart the backend
make devb debug=1
```

* In the root of the rp-cli project, run the following command

```bash
# Start the tests "In Real Life"
make test_irl
```

*N.B.*: By default, the address used by the `rp-cli` tests is `http://0.0.0.0:8000`, if you want to change that, you can modify it directly in the Makefile. Look for the `test_irl` rule.

## Testing code

All the tests are located in the `cmd` folder. They are in the files ending with `_test.go`. The main file being `main_test.go`.
All the other test files contain specific tests for each main subcommand. For example: `applications_test.go`, `projects_test.go`, etc.

Each testing function name needs to start with `Test`. Example: `TestImagesListType()` or `TestImagesAddWithBoardModel()`

Two mocks are implemented in order for the test to be completely standalone. These mocks are started at the beginning of the tests in the `main_test.go` file.

The mocks are:

* The `rp-webserver` mock (to mock the redpesk backend) => located in `rpbckmock/`
* The `redpesk-lad` mock (to mock the local-builder where redpesk-lad is running) => located in `rpladmock\`

# Documentation tips

In the documentation available online, the file `docs/4_commands-list.md` contains the list of all commands available in rp-cli. Of course, this list needs to be updated regularly.
This is why `rp-cli` has a command allowing to generate this commands list: `rp-cli misc cmd-tree`. 

However, in the '.md' file, the alignment needs to be done using space character when the `rp-cli` command use tab characters to align everything. This is why the python script located under
`scripts/rework_cmdtree_output.py` has been developed. To align the output of `rp-cli`, using spaces. A Makefile rule has also been added in order to make everything easier.

Thus, the procedure to follow to update the command list is:

1. Integrate your code inside `rp-cli` to add your new command, as usual
2. Make sure `rp-cli` build, and run `make build`
3. Run `make cmd-list`
4. A new file named `cmd-tree-aligned.txt` is created, it contains the commands list space aligned
5. Copy the content of `cmd-tree-aligned.txt`
6. Paste it inside `docs/4_commands-list.md` at the right place

# Common issues

## Connections issue

You may encounter connection issues between rp-cli and the backend when you change the backend you are working with (typically between production backend and development backend).
When you encounter this issue, check that all the possible configurations have been reset:

* Check all the environment variables linked to rp-cli through `printenv | grep RP_`, when you are not sure about one, unset it (`unset RP_XXX`)
* Check that the configurations in you config file are well set (default configuration file is: **$HOME/.redpesk/rp-cli/rp-cli-config.json**)
* When switching between two backends, its better to use the `onboard` command and let you guide: `rp-cli onboard`
