/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (

	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------

	// applications command
	appsCommand            = "applications"
	appsCommandAlias       = "apps"
	appsCommandShortUsage  = "Applications commands group"
	appsCmdPrjFlag         = "project"
	appsCmdPrjFlagAlias    = "p"
	appsCmdPrjFlagDefault  = ""
	appsCmdPrjFlagUsage    = "ID of the project containing the application(s) targeted by the command. If not used, the ID is retrieved from redpesk."
	appsAddCmdPrjFlagUsage = "[Mandatory] ID of the project that will contain the application."

	// List command
	appsListCmd                      = "list"
	appsListCmdAlias                 = "ls"
	appsListCmdShortUsage            = "List the applications from a project or from the whole redpesk infrastructure"
	appsListCmdBookmarkedFlag        = "bookmarked"
	appsListCmdBookmarkedFlagAlias   = "b"
	appsListCmdBookmarkedFlagDefault = false
	appsListCmdBookmarkedFlagUsage   = "Display only the bookmarked applications"
	appsListCmdTypeFlag              = "type"
	appsListCmdTypeFlagUsage         = "Specify the type of applications to display"
	appsListCmdHeader                = "ID\t Name\t Slug\t Type\t Project"
	appsListCmdVerboseLine0          = "ID:\t"
	appsListCmdVerboseLine1          = "Name:\t"
	appsListCmdVerboseLine2          = "Slug:\t"
	appsListCmdVerboseLine3          = "Parent project:\t"
	appsListCmdVerboseLine4          = "Creation time:\t"
	appsListCmdVerboseLine5          = "Update time:\t"
	appsListCmdVerboseLine6          = "Distributions:\t"
	appsListCmdVerboseLine8          = "Package Name:\t"
	appsListCmdVerboseLine9          = "Description:\t"
	appsListCmdVerboseLine10         = "Source URL:\t"
	appsListCmdVerboseLine11         = "Source Revision:\t"
	appsListCmdVerboseLine12         = "External Specfile:\t"
	appsListCmdVerboseLine13         = "Auto on board tests:\t"
	appsListCmdVerboseLine14         = "Bookmarked:\t"
	appsListCmdVerboseLine15         = "Type:\t"
	appsListCmdVerboseLine16         = "Overrides:\t"
	appsListCmdVerboseLine18         = "Build type:\t"
	appsListCmdVerboseLine17         = "Services:"
	appsListCmdVerboseLine19         = "Auto security audits tests:\t"
	appsListCmdVerboseLine20         = "AutoRSrpmBuild:\t"
	appsListCmdVerboseLine21         = "Audits settings:\t"
	appsListCmdVerboseLine22         = "Specfile type:\t"
	appsListCmdVerboseLine23         = "Ignore missing redtest RPM:\t"
	appsListCmdVerboseLine24         = "Ignore check deps result:\t"

	appDisplayVerboseLightLineNb = 17

	// Get command
	appsGetCmd           = "get <app-ID>"
	appsGetCmdShortUsage = "Get the properties of an application"

	// Add command
	appsAddCmd           = "add"
	appsAddAlias         = "a"
	appsAddCmdShortUsage = "Create a new application"

	appsAddCmdMandDistFlag      = "mandatory-distro"
	appsAddCmdMandDistFlagUsage = "Flag to use to specify a mandatory distribution, this flag can be used several times"
	appsAddCmdOptDistFlag       = "optional-distro"
	appsAddCmdOptDistFlagUsage  = "Flag to use to specify an optional distribution, this flag can be used several times"

	appsAddCmdNameFlag      = "name"
	appsAddCmdNameFlagAlias = "n"
	appsAddCmdNameFlagUsage = "[Mandatory] Name of the application to create"

	appsAddCmdAliasFlag      = "alias"
	appsAddCmdAliasFlagAlias = "a"
	appsAddCmdAliasFlagUsage = "[Optional] Alias for the application name (must be unique)"

	appsAddCmdDescFlag      = "description"
	appsAddCmdDescFlagAlias = "d"
	appsAddCmdDescFlagUsage = "[Optional] Description of the application to create"

	appsAddCmdPkgFlag      = "pkg-name"
	appsAddCmdPkgFlagUsage = "[Mandatory] RPM package name that must match the \"name\" value of the specfile"

	appsAddCmdSrcURLFlag         = "source-url"
	appsAddCmdSrcURLFlagUsage    = "[Optional] GIT URL of source code"
	appsUpdateCmdSrcURLFlagUsage = "[Optional] GIT URL of source code"

	appsAddCmdSrcRevFlag      = "source-rev"
	appsAddCmdSrcRevFlagUsage = "[Optional] GIT revision used for build, it can be a tag (master, 0.0.1, etc.), a branch or a commit ID. Default is master."

	appsAddCmdSpecTypeFlag      = "specfile-type"
	appsAddCmdSpecTypeFlagUsage = "[Optional] Specfile type to use for the application (internal/external_url/relative_path)"

	appsAddCmdSpecLocationFlag      = "specfile-location"
	appsAddCmdSpecLocationFlagUsage = "[Optional] Location of the specfile to use for the app, depending on the type, it can be an URL, a local path or a relative path"

	appsAddCmdAutoTestFlag      = "auto-test"
	appsAddCmdAutoTestFlagUsage = "[Optional] Define if CI tests are automatically started after a successful build"

	appsAddCmdAutoAuditFlag      = "auto-audit"
	appsAddCmdAutoAuditFlagUsage = "[Optional] Define if audits are automatically started after a successful build"

	appsAddCmdDefAuditFlag      = "audits"
	appsAddCmdDefAuditFlagUsage = "[Optional] Define the default audits for the application, this flag can be used several times"

	appsAddCmdAutoSRpmBuildFlag         = "auto-srpm-build"
	appsAddCmdAutoSRpmBuildFlagUsage    = "[Optional] Set/unset cases when to automatically rebuild SRPM (available cases: package files changes, meta files changes, distribution/branches management, application build without valid build srpm)"
	appsAddCmdAutoSRpmBuildAllFlag      = "auto-srpm"
	appsAddCmdAutoSRpmBuildAllFlagUsage = "[Optional] Set/unset all cases to automatically rebuild SRPM "
	autoSrpmOptionsAllTrue              = 15 // 15 corresponds to all 4 srpm auto rebuild options set tot true (1111),If more options are added needs to be changed accordingly

	// definitions of the  srpm auto rebuild options available
	SrpmPackageFileChangeShort             string = "pkg_changes"
	SrpmPackageFileChangeTrueShort         string = "pkg_changes=true"
	SrpmPackageFileChangeFalseShort        string = "pkg_changes=false"
	SrpmMetaFileChangeShort                string = "meta_changes"
	SrpmMetaFileChangeTrueShort            string = "meta_changes=true"
	SrpmMetaFileChangeFalseShort           string = "meta_changes=false"
	SrpmDistroBranchesManagementShort      string = "dist_branch"
	SrpmDistroBranchesManagementTrueShort  string = "dist_branch=true"
	SrpmDistroBranchesManagementFalseShort string = "dist_branch=false"
	SrpmNoValidSrpmBuildShort              string = "no_srpm_bld"
	SrpmNoValidSrpmBuildTrueShort          string = "no_srpm_bld=true"
	SrpmNoValidSrpmBuildFalseShort         string = "no_srpm_bld=false"
	GlobalAutoSrpmRebuildFalse             string = "false"
	GlobalAutoSrpmRebuildTrue              string = "true"

	//-----------------------------------------------------------------

	appsAddCmdIgnoreCheckDepsResultFlag      = "ignore-check-deps"
	appsAddCmdIgnoreCheckDepsResultFlagUsage = "[Optional] Define if check dependencies result is ignored or not"

	appsAddCmdIgnoreMissingRedTestRpmFlag      = "ignore-missing-redtest"
	appsAddCmdIgnoreMissingRedTestRpmFlagUsage = "[Optional] Define if on board testing will fail or not when redtest RPM is missing"

	appsAddCmdServiceFlag       = "service"
	appsAddCmdServicesFlagAlias = "s"
	appsAddCmdServicesFlagUsage = "[Optional] Services the app can get from gitpkgd"

	appsAddCmdBuildTypeFlag        = "build-type"
	appsAddCmdBuildTypeFlagAlias   = "t"
	appsAddCmdBuildTypeFlagDefault = "standard_build_cross"
	appsAddCmdBuildTypeFlagUsage   = "[Optional] Set the build type"

	appsAddCmdActiveBranchFlag         = "active-branch"
	appsAddCmdActiveBranchFlagAlias    = "b"
	appsAddCmdActiveBranchFlagUsage    = "[Optional] Set the active branch name for the application (default: 'main')"
	appsUpdateCmdActiveBranchFlagUsage = "[Optional] Set the active branch for the application"

	appsAddCmdAnsLine0 = "-- Application creation requested by user --"
	appsAddCmdAnsLine1 = "Processing the architecture(s) settings...\t"
	appsAddCmdAnsLine2 = "Processing the distribution(s) settings...\t"
	appsAddCmdAnsLine3 = "Creation of \"%s\" application...\t"
	appsAddCmdAnsLine4 = "Wait for creation confirmation from the backend...\t"

	appsMetadataVersion = "1.1.0"

	// Add From Sample command
	appsAddFromSampleCmd           = "add-from-sample <app-ID>"
	appsAddFromSampleCmdShortUsage = "Create a new application from a sample application retrieved from redpesk factory"
	appsAddFromSampleCmdLongUsage  = `Create a new application from a sample application retrieved from redpesk factory.
In order to have the available applications samples, use the completion: hit 'TAB' after 'rp-cli applications add-from-sample '.`

	// Update command
	appsUpdateCmd           = "update <app-ID>"
	appsUpdateAlias         = "upd"
	appsUpdateCmdShortUsage = "Update an application settings"
	appsUpdateCmdAnsLine0   = "-- Application update requested by user --"
	appsUpdateCmdAnsLine1   = "Update of \"%s\" application...\t"

	appsUpdateCmdDisableServiceFlag       = "disable-services"
	appsUpdateCmdDisableServicesFlagUsage = "[Optional] List of gitpkgd services to disable for the application"

	appsForceStateFlag      = "force-stable-state"
	appsForceStateFlagUsage = "[Hidden] Set to true to force application's state to \"stable\""

	// Delete command
	appsDelCmd           = "delete <app-ID>"
	appsDelAlias         = "del"
	appsDelCmdShortUsage = "Delete an application"
	appsDelCmdAnsLine0   = "-- Application deletion requested by user --"
	appsDelCmdAnsLine1   = "Deletion of \"%s\" application...\t"

	// Bookmark command
	appsBookmarkCmd               = "bookmark <app-ID>"
	appsBookmarkAlias             = "bmark"
	appsBookmarkCmdShortUsage     = "Bookmark an application"
	appsBookmarkCmdResetFlag      = "reset"
	appsBookmarkCmdResetFlagAlias = "r"
	appsBookmarkCmdResetFlagUsage = "Delete the applications's bookmark"
	appsBookmarkCmdAnsLine0       = "-- Application bookmarking requested by user --"
	appsBookmarkCmdAnsLine1       = "Bookmarking of \"%s\" application...\t"
	appsBookmarkCmdAnsLine2       = "Deletion of \"%s\" application's bookmark...\t"
	appsBookmarkCmdAnsLine3       = "\"%s\" application is not bookmarked, nothing to do...\t"
	appsBookmarkCmdAnsLine4       = "\"%s\" application is already bookmarked, nothing to do...\t"

	// Files command group
	appsFilesCmd           = "files"
	appsFilesCmdShortUsage = "Subcommands group relative to application files"

	// Content command
	appsFilesListCmd           = "list <app-ID>"
	appsFilesListAlias1        = "content"
	appsFilesListAlias2        = "con"
	appsFilesListCmdShortUsage = "List the files of an application"

	// Remove command
	appsRemoveCmd           = "remove <app-ID> files..."
	appsRemoveAlias         = "rm"
	appsRemoveCmdShortUsage = "Remove file(s) of an application"

	appsRemoveCmdAnsLine0 = "----- File(s) Removing requested by user ----"
	appsRemoveCmdAnsLine1 = "Removing "

	// Download command
	appsDownloadCmd           = "download <app-ID> [files...]"
	appsDownloadAlias         = "load"
	appsDownloadCmdShortUsage = "Download file(s) of an application"

	appsDownloadCmdAnsLine0 = "----- File(s) Download requested by user ----"
	appsDownloadCmdAnsLine1 = "Downloading "

	// Upload command
	appsUploadCmd           = "upload <app-ID> files..."
	appsUploadAlias         = "upld"
	appsUploadCmdShortUsage = "Upload one or several files for an application"

	appsUploadCmdAnsLine0 = "----- File(s) Upload requested by user ----"
	appsUploadCmdAnsLine2 = "Uploading "

	appsForceAppFlag      = "force-app"
	appsForceAppFlagAlias = "f"
	appsForceAppFlagUsage = "Force the ID given as command line argument to be an application ID"

	// Builds stats command
	appsBuildsStatsCmd           = "stats <app-ID>"
	appsBuildsStatsAlias         = "sts"
	appsBuildsStatsCmdShortUsage = "Display build statistics of the given application"

	appsBuildsStatsCmdLastFlag      = "last"
	appsBuildsStatsCmdLastFlagUsage = "[Optional] Number of last builds to display if verbose is enabled"

	appsBuildsStatsCmdAnsLine0        = "Application ID:\t"
	appsBuildsStatsCmdAnsLine1        = "Application slug:\t"
	appsBuildsStatsCmdAnsLine2        = "Package:\t"
	appsBuildsStatsCmdAnsLine3        = "Done:\t"
	appsBuildsStatsCmdAnsLine4        = "Failed:\t"
	appsBuildsStatsCmdAnsLine5        = "Cancelled:\t"
	appsBuildsStatsCmdAnsLine6        = "Total:\t"
	appsBuildsStatsCmdAnsLine7        = "[Builds status]"
	appsBuildsStatsCmdAnsBuildsHeader = "ID\t Distribution\t Status"

	// -------------

	// Audit command
	appsAuditCmd           = "audit <app-ID>"
	appsAuditAlias         = "adt"
	appsAuditCmdShortUsage = "Start auditing an application"
	appsAuditCmdAnsLine0   = "-- Application audit requested by user --"
	appsAuditCmdAnsLine1   = "Auditing the \"%s\" application...\t"
	appsAuditCmdAnsLine2   = "Checking the specified audit tools...\t"

	appsAuditToolFlag      = "tool"
	appsAuditToolFlagUsage = "[Optional] Tool(s) to use to run the audit, this flag can be used several times  (if not set, use the app's defaults)"

	// Audits command group
	appsAuditsCmd           = "audits"
	appsAuditsCmdShortUsage = "Subcommands group relative to \"audits\" of an application"

	// Audits tools command
	appsAuditsListToolsCmd           = "tools"
	appsAuditsListToolsAlias         = "tls"
	appsAuditsListToolsCmdShortUsage = "List all the tools available to audit an application"
	appsAuditsListToolsHeader        = "Name\t Version\t Type\t Language"
	appsAuditsListToolsAnsLine0      = "Type:\t"
	appsAuditsListToolsAnsLine1      = "Category:\t"
	appsAuditsListToolsAnsLine2      = "Language:\t"
	appsAuditsListToolsAnsLine3      = "Name:\t"
	appsAuditsListToolsAnsLine4      = "Summary:\t"
	appsAuditsListToolsAnsLine5      = "Version:\t"

	// Audits list command
	appsAuditsListCmd              = "list <app-ID>"
	appsAuditsListAlias            = "ls"
	appsAuditsListCmdShortUsage    = "List all the audits of an application"
	appsAuditsListCmdHeader        = "ID\t App.\t Status\t Success/Fail/Skip/Total"
	appsAuditsListCmdVerboseLine0  = "ID:\t"
	appsAuditsListCmdVerboseLine1  = "Application:\t"
	appsAuditsListCmdVerboseLine2  = "Project:\t"
	appsAuditsListCmdVerboseLine3  = "Status:\t"
	appsAuditsListCmdVerboseLine4  = "Success:\t"
	appsAuditsListCmdVerboseLine5  = "Fail:\t"
	appsAuditsListCmdVerboseLine6  = "Skip:\t"
	appsAuditsListCmdVerboseLine7  = "Total:\t"
	appsAuditsListCmdVerboseLine8  = "Creation time:\t"
	appsAuditsListCmdVerboseLine9  = "Update time:\t"
	appsAuditsListCmdVerboseLine10 = "User launcher:\t"
	appsAuditsListCmdVerboseLine11 = "[Detailed results]"
	appsAuditsListCmdVerboseLine12 = "Info:\t"
	appsAuditsListCmdVerboseLine13 = "Unknown:\t"
	appsAuditsListCmdVerboseLine14 = "Low:\t"
	appsAuditsListCmdVerboseLine15 = "Medium:\t"
	appsAuditsListCmdVerboseLine16 = "High:\t"
	appsAuditsListCmdVerboseLine17 = "Critical:\t"
	appsAuditsListCmdVerboseLine18 = "Total:\t"
	appsAuditsListCmdVerboseLine19 = "Overall results:"
	appsAuditsListCmdVerboseLine20 = "Tool:\t"

	auditDisplayVerboseLineNb = 11

	// Get command
	appsAuditsGetCmd           = "get {<app-ID>|<audit-ID>}"
	appsAuditsGetCmdShortUsage = "Get the properties and results of an audit"
	appsAuditsGetCmdLongUsage  = `Get the properties and results of an audit.
Either the application ID or the audit ID can be specified. In the first case the latest audit is retrieved.
If your application ID looks like an audit ID (i.e. it is uniquely an integer), please use the '--force-app' flag.`

	// Audits logs command
	appsAuditsLogsCmd           = "logs <audit-ID>"
	appsAuditsLogsCmdShortUsage = "Download the application audit logs"
	appsAuditsLogsCmdLongUsage  = `Download the application audit logs in the given directory.
Either the application ID or the audit ID can be specified. In the first case the latest audit is retrieved.
If your application ID looks like an audit ID (i.e. it is uniquely an integer), please use the '--force-app' flag.`
	appsAuditsLogsCmdAnsLine0 = "------ Retrieving audit logs archive -----"
	appsAuditsLogsCmdAnsLine1 = "Downloading logs for audit \"%d\"...\t"
	appsAuditsLogsCmdAnsLine2 = "The audit logs for audit \"%d\" are available in: %s\n"
	appsAuditsLogsCmdAnsLine3 = "Retrieve the latest audit ID for this app...\t"
	// -------------

	// Services command
	appsServicesCmd          = "services"
	appsServicesCmdShortDesc = "List the available services for an application built with redpesk"
	appsServicesAnsHeader    = "Name\t Summary\t Version\t Parameters"
	appsServicesAnsLine0     = "Redpesk available services:"
	appsServicesAnsLine1     = "Name:\t"
	appsServicesAnsLine2     = "Parameters:"
	appsServicesAnsLine3     = "Description:\t"
	appsServicesAnsLine4     = "Version:\t"

	// Branch command
	appsBranchCmd          = "branch <app-ID>"
	appsBranchCmdShortDesc = "Create a new branch or switch to an existing one within an application"
	appsBranchCmdLongDesc  = `Create a new branch or switch to an existing one within an application.
If no source branch is specified (using '-s'), the destination branch is set as the active one (like 'git checkout').
If a source branch is specified (using '-s'), a new branch is created from it and is set as the active one (like a 'git checkout -b').
If the default flag is used ('-d'), the destination branch is set as the default one for the application.
If the '--not-active' flag is set the destination branch is not set as the active one for the application.`
	appsBranchCmdAnsLine0 = "Switched to branch '%s' for application '%s'\n"
	appsBranchCmdAnsLine1 = "Switched to a new branch '%s' for application '%s'\n"
	appsBranchCmdAnsLine2 = "Creation of a new branch '%s' for application '%s'\n"
	appsBranchCmdAnsLine3 = "Related distributions list updated"

	appsBranchSourceFlag      = "source"
	appsBranchSourceFlagAlias = "s"
	appsBranchSourceFlagUsage = "[Optional] Source branch to use when creating a new one"

	appsBranchDestinationFlag      = "destination"
	appsBranchDestinationFlagAlias = "d"
	appsBranchDestinationFlagUsage = "[Mandatory] Destination branch to create/switch to"

	appsBranchDefaultFlag      = "default"
	appsBranchDefaultFlagUsage = "[Optional] Set the destination branch as the default one for the application"

	appsBranchNotActiveFlag      = "not-active"
	appsBranchNotActiveFlagUsage = "[Optional] Do not set the destination branch as the active one"

	appsBranchDistrosFlag      = "distributions"
	appsBranchDistrosFlagUsage = "[Optional] Comma separated list of distributions associated with destination branch"

	appsBranchResetDistrosFlag      = "reset-distros"
	appsBranchResetDistrosFlagAlias = "r"
	appsBranchResetDistrosFlagUsage = "[Optional] Reset the distributions list associated with the destination branch"

	// Branches command group
	appsBranchesCmd           = "branches"
	appsBranchesCmdShortUsage = "Subcommands group relative to \"branches\" of an application"

	// Branches list command
	appsBranchesListCmd           = "list <app-ID>"
	appsBranchesListAlias         = "ls"
	appsBranchesListCmdShortUsage = "List all the branches of an application"

	// Branches delete command
	appsBranchesDelCmd           = "delete <app-ID> --branch <branch-ID>"
	appsBranchesDelCmdAlias      = "del"
	appsBranchesDelCmdShortUsage = "Delete the branch <branch-ID> from the application <app-ID>"
	appsBranchesDelCmdAnsLine0   = "Deleted branch '%s' in application '%s'\n"

	appsBranchFlag      = "branch"
	appsBranchFlagAlias = "b"
	appsBranchFlagUsage = "[Mandatory] Branch to delete"

	// Copy app command
	appsCopyCmd          = "copy <app-ID> --destination-project <destination-project>"
	appsCopyAlias        = "cp"
	appsCopyCmdShortDesc = "Copy the application to another project."
	appsCopyCmdLongDesc  = "Copy the application to another project. Only the configuration of the application will be copied (builds and tests are omitted)"
	appsCopyCmdAnsLine0  = "Application '%s' copied in destination project '%s'\n"

	appCopyCmdDestinationPrjFlag      = "destination-project"
	appCopyCmdDestinationPrjAlias     = "d"
	appCopyCmdDestinationPrjFlagUsage = "ID of the destination project where the application will be copied"

	// Refresh files package command
	appsRefreshFilesPkgCmd       = "refresh-files-pkg <app-ID>"
	appsRefreshFilesPkgAlias     = "refresh"
	appsRefreshFilesPkgShortDesc = "Refresh gitpkg generated files (including tarballs) for the application"
	appsRefreshFilesPkgAnsLine0  = "------ Files refresh requested by the user -----"
	appsRefreshFilesPkgAnsLine1  = "Refreshing gitpkg generated files for \"%s\"...\t"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	appCreationInfoMsg = "Asking for the creation of the application: \"%s\""
	usePrjDistrosMsg   = "-> No distributions set, using project ones\n"
	usePrjArchMsg      = "-> No architectures set, using project ones\n"
	appUpdateInfoMsg   = "Asking for the update of the application: \"%s\""

	// Error messages
	objectIDNotSetMsg               = "no %s ID argument in the command line"
	objectIDRequiredMsg             = "an %s ID is required for the wanted operation, please provide one"
	appNotFoundMsg                  = "application not found. Either the application does not exist or you are not allowed to access it"
	appPrjFlagNotSetMsg             = "impossibility to get the parent project for this application"
	appPrjFlagRequiredMsg           = "please verify the ID of your application and that this application exists"
	appPrjFlagNotSetCreateMsg       = "no project ID set in the command"
	appPrjFlagRequiredCreateMsg     = "please provide a valid parent project ID with the --project flag"
	appPkgFlagNotSetMsg             = "no package name set in the command line"
	appPkgFlagRequiredMsg           = "please provide a valid package name for the application"
	appArchNotSetMsg                = "no architecture (matching with the project ones) have been found. Please provide at least one"
	appDistNotSetMsg                = "no distribution (matching with the project ones) have been found. Please provide at least one"
	appNoDistByUser                 = "no distribution set by user, using the one(s) from %s project"
	appNoArchByUser                 = "no architecture set by user, using the one(s) from %s project"
	appMandArchMsg                  = "the architecture %s is mandatory for the project %s, setting it anyway..."
	appMandDistMsg                  = "the distribution %s is mandatory for the project %s, setting it anyway..."
	appSpecTypeNotAuthMsg           = "this specfile type is not authorized, please use either 'internal', 'external_url' or 'relative_path'"
	appIdentifierNotFound           = "no application has been found with the identifier \"%s\", check out the previous warning messages that may give you an explanation"
	appSeveralIdentifierFound       = "several \"%s\" applications have been found. Please use the \"--project\" flag to specify a parent project"
	appBookmarkNotChangedMsg        = "a problem occurred when setting/resetting the bookmark, it has not be taken into account"
	appBuildErrorMsg                = "the application's build encounters an error (failed or canceled)"
	appTestsFailedMsg               = "the application's tests have failed"
	appTestsTimedOutMsg             = "the application's tests have reached the time-out limit"
	appTestsAbortedMsg              = "the application's tests have been aborted"
	appServiceNameNotAvailable      = "the service name furnished by the user (\"%s\") is not available on the factory"
	appServiceParamNotAvailable     = "the parameter name furnished by the user (\"%s\") is not available for the service \"%s\""
	appServiceParamValueNotRight    = "the parameter value furnished by the user (\"%s\") is not consistent with the type \"%s\" of the parameter \"%s\"; err: %v"
	appServiceParamTypeNotSupported = "the type (\"%s\") of the parameter \"%s\" is not supported"
	appSampleNotFoundMsg            = "the application \"%s\" does not exists in the available samples..."
	objectIDNotInteger              = "the %s's ID needs to be an integer and this is not the case"
	auditToolNotAvailable           = "the following audit tool is not available in the redpesk factory: \"%s\""
	noAuditFoundInAppMsg            = "no audit has been found for this application"
	distroNotAvailableMsg           = "the specified distribution \"%s\" is not available for the object named \"%s\""
	appUUIDOrPrjUUIDNeedToBeSet     = "internal error: appUUID or prjUUID needs to be set"
	noBoardModelFoundMsg            = "the specified board model \"%s\" is not available for tests on the factory"
	dstBranchEmptyMsg               = "the destination branch is empty, please specify one with the --destination flag"
	delBranchEmptyMsg               = "the branch name to delete is empty, please specify one with the --branch flag"
	branchNotFoundInAppMsg          = "the branch named \"%s\" has not been found for the specified application"
	noBuildForApplication           = "the specified application (UUID: '%s') does not have any build"
	copyAppDestPrjEmptyMsg          = "the destination project name is empty, please specify one with the --destination-project flag"
	appUploadFileDoesNotExists      = "the specified file does not exist: %s"
	appAutoSrpmParamNotExist        = "the parameter (\"%s\") is not a valid auto srpm rebuilds parameter"
	appAutoSrpmRebuildNotValid      = "invalid auto-srpm flag value, use only 'true' or 'false'"

	// Warning messages
	appUpdateDisableServiceNotExisting = "the specified service \"%s\" cannot be disable because it is not in the service list"
	autoSrpmBuildIncompatibleFlags     = "incompatible flags have been detected, if global auto-srpm flag is set auto-srpm-build flags will be ignored"
	autoSrpmBuildParameterFalse        = "please note that disabling some options of the automatic SRPM build may result in undesired behavior. Please use this manual mode only if you are familiar with the SRPM build process."
	appIDNotFoundOnTryX                = "the application identifier '%s' has not been found on attempt #%d"
	tooManyAppIDFoundOnTryX            = "too many application identifiers have been found on attempt #%d. Please use the \"--project\" flag to specify a parent project"
	appExistsButNotWithThisPrj         = "some apps exists with the identifiers '%s', but not with the specified project"

	// Debug messages
	appCreationDebugMsg         = "Asking for the creation of the application: %+v"
	appUpdateDebugMsg           = "Asking for the update of the application: %+v"
	applicationTestLogsDwnldMsg = "Downloading %s from %s"
	// ----------------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
