/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage

	Licensees holding valid commercial IoT.bzh licenses may use this file in
	accordance with the commercial license agreement provided with the
	Software or, alternatively, in accordance with the terms contained in
	a written agreement between you and The IoT.bzh Company. For licensing terms
	and conditions see https://www.iot.bzh/terms-conditions. For further
	information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage

	Alternatively, this file may be used under the terms of the GNU General
	Public license version 3. This license is as published by the Free Software
	Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
	of this file. Please review the following information to ensure the GNU
	General Public License requirements will be met
	https://www.gnu.org/licenses/gpl-3.0.html.

$RP_END_LICENSE$
*/
package cmd

import (
	"testing"
)

const (
	boardModelsDisplayColNb = 5
)

// TestBoardModelsList is the function allowing to test if
// the command "rp-cli board-models list" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardModelsList(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":       `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":     `.+`,
		"Category": `^(OTA|RTM)$`,
		"Arch.":    `^(x86_64|aarch64)$`,
		"Virtual":  `^(true|false)$`,
	}

	// Run the command and the tests
	checkCmdAnsKeysRegexpCol(test, boardModelsDisplayColNb, regexpMap, boardModelsCommand, "list")
}

// TestBoardModelsListVerbose is the function allowing to test if
// the command "rp-cli board-models list -v" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardModelsListVerbose(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":            `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":          `.+`,
		"Creation time": `.+`,
		"Update time":   `.+`,
		"Category":      `^(OTA|RTM)$`,
		"Architecture":  `^(x86_64|aarch64)$`,
		"CPU":           `^\[Not set\]$`,
		"Virtual":       `^(true|false)$`,
	}

	// Run the command and the tests (no verbose and verbose, since this is the same result)
	checkCmdAnswerListKeysRegexp(test, boardModelsDisplayListLineNb, "", regexpMap, boardModelsCommand, "list", "-v")
}

// TestBoardModelsGet is the function allowing to test if
// the command "rp-cli board-models get" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardModelsGet(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":       `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":     `^bcm2711-rpi-4-b$`,
		"Category": `^RTM$`,
		"Arch.":    `^aarch64$`,
		"Virtual":  `^false$`,
	}

	// Run the command and the tests
	checkCmdAnsKeysRegexpCol(test, boardModelsDisplayColNb, regexpMap, boardModelsCommand, "get", "bcm2711-rpi-4-b")

	// Try to get with the UUID
	checkCmdAnsKeysRegexpCol(test, boardModelsDisplayColNb, regexpMap, boardModelsCommand, "get", "b8471607-3f6d-4f49-b8f0-66732678ca3c")
}

// TestBoardModelsGetVerbose is the function allowing to test if
// the command "rp-cli board-models get -v" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardModelsGetVerbose(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":            `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":          `^bcm2711-rpi-4-b$`,
		"Creation time": `.+`,
		"Update time":   `.+`,
		"Category":      `^RTM$`,
		"Architecture":  `^aarch64$`,
		"CPU":           `^\[Not set\]$`,
		"Virtual":       `^false$`,
	}

	// Run the command and the tests (no verbose and verbose, since this is the same result)
	checkCmdAnswerListKeysRegexp(test, boardModelsDisplayListLineNb, "", regexpMap, boardModelsCommand, "get", "bcm2711-rpi-4-b", "-v")
}

// --------------------------------------------------------------
// --------------------------------------------------------------
