/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage

	Licensees holding valid commercial IoT.bzh licenses may use this file in
	accordance with the commercial license agreement provided with the
	Software or, alternatively, in accordance with the terms contained in
	a written agreement between you and The IoT.bzh Company. For licensing terms
	and conditions see https://www.iot.bzh/terms-conditions. For further
	information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage

	Alternatively, this file may be used under the terms of the GNU General
	Public license version 3. This license is as published by the Free Software
	Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
	of this file. Please review the following information to ensure the GNU
	General Public License requirements will be met
	https://www.gnu.org/licenses/gpl-3.0.html.

$RP_END_LICENSE$
*/
package cmd

import "testing"

const (
	boardDisplayColNb = 6
)

// TestBoardsList is the function allowing to test if
// the command "rp-cli boards list" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardsList(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":       `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":     `.+`,
		"Category": `^(OTA|RTM)$`,
		"Model":    `.+`,
		"Arch.":    `^(x86_64|aarch64)$`,
		"Status":   `^(offline|connected|good|maintenance)$`,
	}

	// Run the command and the tests
	checkCmdAnsKeysRegexpCol(test, boardDisplayColNb, regexpMap, boardsCommand, "list")
}

// TestBoardsListVerbose is the function allowing to test if
// the command "rp-cli boards list -v" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardsListVerbose(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":            `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":          `.+`,
		"Creation time": `.+`,
		"Update time":   `.+`,
		"Creator":       `^\[Not set\]$`,
		"Category":      `^(OTA|RTM)$`,
		"Model":         `.+`,
		"IP":            `.*`,
		"Status":        `^(offline|connected|good|maintenance)$`,
		"Architecture":  `^(x86_64|aarch64)$`,
		"Distribution":  `^\[Not set\]$`,
	}

	// Run the command and the tests (no verbose and verbose, since this is the same result)
	checkCmdAnswerListKeysRegexp(test, boardDisplayListLineNb, "", regexpMap, boardsCommand, "list", "-v")
}

// TestBoardsGet is the function allowing to test if
// the command "rp-cli boards get" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardsGet(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":       `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":     `^qemu-redpesk01$`,
		"Category": `^RTM$`,
		"Model":    `^qemu-redpesk$`,
		"Arch.":    `^x86_64$`,
		"Status":   `^good$`,
	}

	// Run the command and the tests
	checkCmdAnsKeysRegexpCol(test, boardDisplayColNb, regexpMap, boardsCommand, "get", "qemu-redpesk01")

	// Try to get with the UUID
	checkCmdAnsKeysRegexpCol(test, boardDisplayColNb, regexpMap, boardsCommand, "get", "57a1a5e4-1caf-4f3b-bcff-a720b77b9dd6")
}

// TestBoardsGetVerbose is the function allowing to test if
// the command "rp-cli boards get -v" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestBoardsGetVerbose(test *testing.T) {

	// Create the map containing the regexp we want to match in the answer
	regexpMap := map[string]string{
		"ID":            `[a-f0-9]{8}(-[a-f0-9]{4}){3}-[a-f0-9]{12}`,
		"Name":          `^qemu-redpesk01$`,
		"Creation time": `.+`,
		"Update time":   `.+`,
		"Creator":       `^\[Not set\]$`,
		"Category":      `^RTM$`,
		"Model":         `^qemu-redpesk$`,
		"IP":            `.*`,
		"Status":        `^good$`,
		"Architecture":  `^x86_64$`,
		"Distribution":  `^\[Not set\]$`,
	}

	// Run the command and the tests (no verbose and verbose, since this is the same result)
	checkCmdAnswerListKeysRegexp(test, boardDisplayListLineNb, "", regexpMap, boardsCommand, "get", "qemu-redpesk01", "-v")
}
