/*
Copyright © 2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// Test command for app (specific)
	appsTestCmdImageFlag      = "image"
	appsTestCmdImageFlagAlias = "i"
	appsTestCmdImageFlagUsage = "[Optional] Image ID (slug or UUID) to use for test"

	// Test command for image (specific)
	imgsTestCmdAppFlag      = "app"
	imgsTestCmdAppFlagAlias = "a"
	imgsTestCmdAppFlagUsage = "[Optional] Application ID to use for test"

	imgsTestCmdAppProjectFlag      = "app-project"
	imgsTestCmdAppProjectFlagUsage = "[Optional] Project containing the app to use for test"

	// Test command (generic)
	genericTestCmd           = "test {<%s>|<build-ID>}"
	genericTestAlias         = "tst"
	genericTestCmdShortUsage = "Start a test run for an %s"
	genericTestCmdLongUsage  = `Start a test run for an %s.
Either the %s ID or the build ID can be specified. In the first case the latest build is retrieved.
If your %s ID looks like a build ID (i.e. it is uniquely an integer), please use the '%s' flag.`

	genericTestCmdBoardModelFlag      = "board-model"
	genericTestCmdBoardModelFlagAlias = "b"
	genericTestCmdBoardModelFlagUsage = "[Optional] Board model (D.U.T.) to use for the test"

	genericTestCmdTimeOutFlag      = "time-out"
	genericTestCmdTimeOutFlagUsage = "[Optional] Time-out, in minute, for the tests"

	genericTestCmdProgressFlag        = "progress"
	genericTestCmdProgressFlagUsage   = "[Optional] Request rp-cli to display the progress events"
	genericTestCmdProgressFlagDefault = false

	genericTestCmdCommentFlag      = "comment"
	genericTestCmdCommentFlagAlias = "c"
	genericTestCmdCommentFlagUsage = "[Optional] Additional information to save with the test data"

	genericTestCmdAnsLine0 = "-- %s test requested by user --\n"
	genericTestCmdAnsLine1 = "Testing the %s on build %d...\t"
	genericTestCmdAnsLine2 = "------- %s test succeeded ------\n"
	genericTestCmdAnsLine3 = "-------- %s test failed --------\n"
	genericTestCmdAnsLine4 = "------ %s test timed-out -------\n"
	genericTestCmdAnsLine5 = "------- %s test aborted --------\n"

	genericTestLiveCmdVerbose1Line   = "[STATE CHANGE] %-12v -- TOTAL => Success: %-4v - Fail: %-4v - Skip: %-4v"
	genericTestLiveCmdNoVerbose1Line = "[STATE CHANGE] %-12v -- TOTAL => %-4v"

	genericTestProgressVerbose1Line = "[PROGRESS] #%-4v - %-4v -- TOTAL => Success: %-4v - Fail: %-4v - Skip: %-4v"
	genericTestProgNoVerboseLine0   = "[PROGRESS] #%-4v - %-4v -- TOTAL => %-4v"

	genericTestConsVerbose1Line = "[OUTPUT] %s > %s"

	genericTestCmdVerboseLine0  = "Test ID:\t"
	genericTestCmdVerboseLine1  = "Application ID:\t"
	genericTestCmdVerboseLine2  = "Status:\t"
	genericTestCmdVerboseLine3  = "Build ID:\t"
	genericTestCmdVerboseLine4  = "Succeeded tests number:\t"
	genericTestCmdVerboseLine5  = "Failed tests number:\t"
	genericTestCmdVerboseLine6  = "Skipped tests number:\t"
	genericTestCmdVerboseLine7  = "Total tests number:\t"
	genericTestCmdVerboseLine8  = "Image ID:\t"
	genericTestCmdVerboseLine9  = "Board model:\t"
	genericTestCmdVerboseLine10 = "Comment:\t"
	genericTestCmdVerboseLine11 = "Start time:\t"

	// Tests command group
	genericTestsCmd           = "tests"
	genericTestsCmdShortUsage = "Group of subcommands relative to \"tests\" of an %s"

	// Tests list command
	genericTestsListCmd           = "list <%s>"
	genericTestsListAlias         = "ls"
	genericTestsListCmdShortUsage = "List all the test runs done on an %s"

	genericTestsListHeader = "ID\t Status"

	// Applications tests
	appTestsDisplayVerboseLineNb = 12

	// Get command
	genericTestsGetCmd           = "get {<%s>|<test-ID>}"
	genericTestsGetCmdShortUsage = "Get the properties of a test"
	genericTestsGetCmdLongUsage  = `Get the properties of a test.
Either the %s ID or the test ID can be specified. In the first case the latest test is retrieved.
If your %s ID looks like a test ID (i.e. it is uniquely an integer), please use the '%s' flag.`

	// Tests logs command
	genericTestLogsCmd           = "logs {<%s>|<test-ID>}"
	genericTestLogsCmdShortUsage = "Download the %s test logs"
	genericTestLogsCmdLongUsage  = `Download the %s test logs in a directory.
Either the %s ID or the test ID can be specified. In the first case the latest test is retrieved.
If your %s ID looks like a test ID (i.e. it is uniquely an integer), please use the '%s' flag.`
	genericTestLogsCmdAnsLine0 = "------ Retrieving test logs files -----"
	genericTestLogsCmdAnsLine1 = "Downloading logs for test \"%s\"...\n"
	genericTestLogsCmdAnsLine2 = "No logs available for test \"%s\"\n"
	genericTestLogsCmdAnsLine3 = "A problem appeared while downloading \"%s\": %v\n"
	genericTestLogsCmdAnsLine4 = "The test logs for test \"%s\" are available in: %s\n"
	genericTestLogsCmdAnsLine5 = "Retrieve the latest test ID for this app...\t"

	// Tests cancel command
	genericTestCancelCmd           = "cancel {<%s>|<test-ID>}"
	genericTestCancelCmdShortUsage = "Cancel a test currently running"
	genericTestCancelCmdLongUsage  = `Cancel a test currently running.
Either the %s ID or the test ID can be specified. In the first case the latest test is retrieved.
If your %s ID looks like a test ID (i.e. it is uniquely an integer), please use the '%s' flag.`
	genericTestCancelCmdAnsLine0 = "--- Test cancelling requested by user ---"
	genericTestCancelCmdAnsLine1 = "Cancelling test with ID \"%s\"...\t"

	// Tests stats command
	genericTestsStatsCmd           = "stats <%s>"
	genericTestsStatsAlias         = "sts"
	genericTestsStatsCmdShortUsage = "Display test statistics of the given %s"

	genericTestsStatsCmdLastFlag      = "last"
	genericTestsStatsCmdLastFlagUsage = "[Optional] Number of last tests to display if verbose is enabled"

	appsTestsStatsCmdAnsLine0 = "Application ID:\t"
	appsTestsStatsCmdAnsLine1 = "Application slug:\t"
	appsTestsStatsCmdAnsLine2 = "Package:\t"

	imgsTestsStatsCmdAnsLine0 = "Image ID:\t"
	imgsTestsStatsCmdAnsLine1 = "Image slug:\t"

	genericTestsStatsCmdAnsLine3        = "Succeeded:\t"
	genericTestsStatsCmdAnsLine4        = "Failed:\t"
	genericTestsStatsCmdAnsLine5        = "Cancelled:\t"
	genericTestsStatsCmdAnsLine6        = "Total:\t"
	genericTestsStatsCmdAnsLine7        = "[Tests status]"
	genericTestsStatsCmdAnsBuildsHeader = "ID\t Type\t Status"
)
