/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// Application name
	applicationName         = "rp-cli"
	applicationNameASCIIArt = `██████  ██████         ██████ ██      ██ 
██   ██ ██   ██       ██      ██      ██ 
██████  ██████  █████ ██      ██      ██ 
██   ██ ██            ██      ██      ██ 
██   ██ ██             ██████ ███████ ██ 
                                         
                                         `

	// Application details
	appCopyright             = "Copyright (C) 2020-%s \033[35mIoT.bzh\033[0m - \033[31mRedpesk®\033[0m"
	defaultLogLevel          = "warn"
	defaultConfigEnvFilename = "cli-config.env"
	// Environment variable prefix used by the application
	envPrefix = "RP"

	// Authors
	author1 = "Armand Bénéteau <armand@iot.bzh>"
	author2 = "Sébastien Douheret <sebastien@iot.bzh>"

	// Application description
	appShortDesc = "Command line tool for Redpesk platform"
	appLongDesc  = "\n\033[31m" + applicationNameASCIIArt + "\033[0m\n* \033[31mRedPesk\033[0m Command Line Interface *\n\033[31m" + fishASCIIArt + "\033[0m\n\n" + applicationName + ` is a command line tool to interact with the Redpesk platform.
For the moment, it interacts with the redpesk factory and local-builder.

` + "\033[31mFIRST RUN\033[0m" + `

If it is you first time with rp-cli, please consider running the 'rp-cli onboard' command in order to interactively configure rp-cli on your system.
More detailed information can be found here: https://docs.redpesk.bzh/docs/en/master/redpesk-factory/rp_cli/2_configuration.html.

N.B.: In order to communicate with a Redpesk backend, an access token is needed. If none is set, this token is requested
interactively when rp-cli is used for the first time.

` + "\033[31mREDPESK FACTORY CONNECTIONS\033[0m" + `

You can manage the connections with the redpesk factory (or factories) using the 'rp-cli connections' sub-commands.
Run 'rp-cli connections -h' in order to get further information on these commands.

Basically, you can add a new connection with the 'rp-cli connections add' command.
To use the connection newly added, use the 'rp-cli connections use' command.

` + "\033[31mFULL LIST OF RP-CLI COMMANDS\033[0m" + `

If you want to display the full list of available rp-cli commands as a tree, simply run 'rp-cli misc cmd-tree'.

` + "\033[31mCOMMAND RESEARCH\033[0m" + `

You can use rp-cli to look for a command. In order to do that, use the 'rp-cli misc cmd-search <pattern>' command.
The pattern given as argument is searched in the command names, short descriptions and long descriptions.
A regular expression can also be used, please give the '-r' flag if it is the case.
Run 'rp-cli misc cmd-search -h' in order to get further information on this command.`

	appExample = `  # Get server version
  ` + applicationName + ` misc version

  # Get help for 'projects' sub-command
  ` + applicationName + ` projects --help`

	// Flag used for "Not set" flag
	flagUpdateKeepCurrentValue = "__KEEP_CURRENT_VALUE__"

	// Onboard command
	rootOnBoardCmd                 = "onboard"
	rootOnBoardCmdDesc             = "Set up the whole rp-cli configuration interactively"
	rootOnBoardAnsLineReq0         = "Do you want to configure the redpesk backend connection? (Y/n)"
	rootOnBoardAnsLineReq1         = "Do you want to configure the redpesk local-builder connection? (Y/n)"
	rootOnBoardAnsLine0            = "-- Backend link configuration requested by user --"
	rootOnBoardAnsLine1            = "Deleting the eventual cookie file...\t"
	rootOnBoardAnsLine2            = "Creation/Update of the configuration file...\t"
	rootOnBoardAnsLine3            = "Modification of the token file...\t"
	rootOnBoardAnsLocalLine3       = "Modification of the local builder file...\t"
	rootOnBoardAnsAliasReq1        = "Please enter the alias of the connection you want to change/create, then press enter:"
	rootOnBoardAnsAliasReq2        = "If you want to change/create the default connection, press enter directly"
	rootOnBoardAnsURLReq           = "Please enter the URL of the redpesk backend you want to interact with, then press enter:"
	rootOnBoardAnsURLLocalReq      = "Please enter the IP of the local builder you want to interact with (ex: 10.231.232.2), then press enter:"
	rootOnBoardAnsFailIPCheck      = "The given IP (%s) does not pass the connection check. Do you want to modify it? (Y/n)\n"
	rootOnBoardAnsLocalUseDefDir   = "The default mounted directory (%s) exists on the host, should it be used as '%s' directory? (Y/n)\n"
	rootOnBoardAnsLocalDirToUse    = "Please enter the location of the directory to use as '%s' directory (default: '%s')\n"
	rootOnBoardAnsLocalDirNotExist = "The specified directory (%s) does not exists, do you want to create it? (Y/n)"
	rootOnBoardAvailConnectLine    = "Current available connections:"
	rootOnBoardNoConnectAvailLine  = rootOnBoardAvailConnectLine + " [NONE]"
	connectionAliasLabel           = "Alias:\t"
	connectionURLLabel             = "Server URL:\t"
	connectionTokenLabel           = "Access token:\t"
	rootOnBoardLocalAnsLine0       = "-- Local builder link configuration requested by user --"

	// Configuration file possible location
	configFileHomePath     = "/.redpesk/rp-cli/"
	cookiesDirRelativePath = "cookies/"
	configFileEtcPath      = "/etc/redpesk/rp-cli/"

	// Access token filename
	accessTokenFile = "access_token.json"

	// Local builder connection filename
	localBuilderFile = "local_builder.json"

	// Local builder alias
	localBuilderAlias = "local_builder"

	globalOKLabel = "[OK]\n"
	globalKOLabel = "[KO]\n"

	noConnectParamsSetMsg = "No valid connection parameters saved with the alias \"%s\"\n"
	createTokenMsg0       = "\nPlease visit %s with your favorite browser to create your access token!\n"
	createTokenMsg1       = "The token section is available in your profile page. Please, paste your token here and press enter:"
	rpCliPrompt           = "> "

	// --------------------------------------------------------------
	// Global flags used in the application -------------------------
	// --------------------------------------------------------------

	// Configuration file
	configFileFlag      = "config"
	configFileFlagAlias = "C"
	configFileFlagUsage = "Config file containing the user options (default are $HOME/.redpesk/rp-cli/rp-cli-config.json or /etc/redpesk/rp-cli/rp-cli-config.json)"
	configFileEnvVar    = "RP_CONFIG"
	configFileDefault   = "rp-cli-config"
	// Log level
	logLevelFlag      = "loglevel"
	logLevelFlagAlias = "L"
	logLevelFlagUsage = "Logging level (supported levels: panic, fatal, error, warn, info, debug)"
	// Log filename
	logFileFlag        = "logfilename"
	logFileFlagDefault = "stderr"
	logFileFlagUsage   = "Filename where logs will be redirected"
	// Server Alias
	serverAliasFlag      = "serveralias"
	serverAliasFlagUsage = "Alias for the connection parameters to use to connect on the Redpesk server"
	// Local-builder Alias
	localBuilderAliasFlag      = "localbuilderalias"
	localBuilderAliasFlagUsage = "Alias for the connection parameters to use to connect on the local-builder"
	// Timestamp
	timestampFlag        = "timestamp"
	timestampFlagAlias   = "T"
	timestampFlagDefault = false
	timestampFlagUsage   = "Prefix output with timestamp [NOT IMPLEMENTED YET]"
	// Non-blocking option
	nonBlockingFlag        = "nonblocking"
	nonBlockingFlagDefault = false
	nonBlockingFlagUsage   = "When set, rp-cli never waits for events on the websocket (builds, tests, etc.)"
	// Raw output option
	rawOutputFlag        = "rawoutput"
	rawOutputFlagDefault = false
	rawOutputFlagUsage   = "When set, rp-cli output only machine readable text (json) that corresponds to the Redpesk backend answers"
	// No error option
	noErrorFlag        = "noerror"
	noErrorFlagDefault = false
	noErrorFlagUsage   = "When set, rp-cli always exit with the '0' status even if an error happened, this can be useful in scripts"
	// No pager option
	noPagerFlag        = "nopager"
	noPagerFlagAlias   = "F"
	noPagerFlagDefault = false
	noPagerFlagUsage   = "When set, rp-cli never display objects list page by page but print all the objects in the terminal"
	// No header option
	NoHeaderFlag        = "noheader"
	NoHeaderFlagDefault = false
	NoHeaderFlagUsage   = "When set, rp-cli does not print list headers (useful for scripting)"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------
	objectSlugDisplayMsg = "Slug of the created %s: %s"

	// --------------------------------------------------------------
	// Warning messages ---------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------

	// Error messages
	logLevelInvalidMsg             = "invalid log level : \"%v\"\n"
	logFileCreationErr             = "cannot create log file %s"
	processSignalCallBackErr       = "error while initializing the signals callbacks: %v"
	pbFlagMainPrefix               = "a problem occurred while getting the "
	noServerURLError               = "no server URL is specified"
	noInteractiveTokenInCompletion = "the interactive way of requesting connection parameters is not available in completion"
	errOnConfigFileReading         = "[Configuration file] %s"
	runtimeErrorMsg                = "something wrong happened while running rp-cli"
	runtimeErrorDetailsMsg         = "error: %s\n"
	runtimeErrorStackTraceMsg      = "Stacktrace: \n\n%s\n"
	runtimeErrorCrashReportMsg     = "a crash report file, named %s, has been created inside %s"
	yesNoNotRespectedErrorMsg      = "please only use 'y' or 'n' as answer"
	localBuilderAliasForbidden     = "this alias can't be used for a backend connection"
	noLocalServerURLError          = "no local builder configuration found"
	errWhileRetrievingChildCmd     = "the following error appeared while retrieving the child command: %v"
	flagMustBePrecededMsg          = "Flag \"--%s\" must be preceded by the \"--%s\" flag"

	// Information messages
	configFileInfoPrefix   = "Using config file:"
	logFileInfoPrefix      = "Logging to file: %s"
	versionInfoMsg         = applicationName + " version: %s"
	projectCreationInfoMsg = "Asking for the creation of the project: \"%s\""

	// Warning messages
	disableWSReconnection = "Websocket reconnection routine disabled because '%s' event received"

	// Debug messages
	envMsgPrefix            = "\nEnvironment: %v\n"
	processSignalSendPrefix = "Send signal %v (from main)"
	endOfAppMsg             = "End " + applicationName + " with signal"
	projectCreationDebugMsg = "Asking for the creation of the project: %+v"
	accessTokenDebugMsg     = "Access token used: %s"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Curl command -------------------------------------------------
	// --------------------------------------------------------------
	repoCurlAddTemplate = `curl -fsSL '%s/install_repo.sh?token=%s' | bash`

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// Fish ASCII art
	fishASCIIArt = `
  |\   \\\\__     o
  | \_/    o \    o
  > _   (( <_  oo
  | / \__+___/
  |/     |/`

	// Beer ASCII art
	beerASCIIArt = `
                         .sssssssss.
                   .sssssssssssssssssss
                 sssssssssssssssssssssssss
                ssssssssssssssssssssssssssss
                 @@sssssssssssssssssssssss@ss
                 |s@@@@sssssssssssssss@@@@s|s
          _______|sssss@@@@@sssss@@@@@sssss|s
        /         sssssssss@sssss@sssssssss|s
       /  .------+.ssssssss@sssss@ssssssss.|
      /  /       |...sssssss@sss@sssssss...|
     |  |        |.......sss@sss@ssss......|
     |  |        |..........s@ss@sss.......|
     |  |        |...........@ss@..........|
      \  \       |............ss@..........|
       \  '------+...........ss@...........|
        \________ .........................|
                 |.........................|
                /...........................\
               |.............................|
                  |.......................|
                      |...............|
`

	// Serious ASCII Art
	seriousASCIIArt = `
	 _    _ _                                                                            _                   ___
	| |  | | |                                                                          (_)                 |__ \
	| |  | | |__  _   _    __ _ _ __ ___   _   _  ___  _   _   ___  ___    ___  ___ _ __ _  ___  _   _ ___     ) |
	| |/\| | '_ \| | | |  / _' | '__/ _ \ | | | |/ _ \| | | | / __|/ _ \  / __|/ _ \ |__| |/ _ \| | | / __|   / /
	\  /\  / | | | |_| | | (_| | | |  __/ | |_| | (_) | |_| | \__ \ (_) | \__ \  __/ |  | | (_) | |_| \__ \  |_|
	 \/  \/|_| |_|\__, |  \__,_|_|  \___|  \__, |\___/ \__,_| |___/\___/  |___/\___|_|  |_|\___/ \__,_|___/  (_)
               __/ |                    __/ |
              |___/                    |___/
                                                                   /
                     .@@*                                    .@@@@&
                 *@@@@      ***#@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
               @@@@&  *@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@& %@
            #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@#
           @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
         *@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
         @@@@@@@@@@@@@@@@@@@@@@@@@@@(              *@@@@@@@@@@@,
          @@@@@@@@@@@@@@@@@@@@@@#                 .@@@@@@@@@@@@
           *@@@@@@@@@@@@@@@@@@                  ,@@@@@@@@@@@.(@
              @@@@@@@@@@@@@@                  @@@@@@@@@@@*   ,@@
                 @@@@@@@@@@                      &@@@@@@  /@   @
                @    .%@@@.                        #@@@* @     (@
               &*                                   ,@@/.@. @  @@
               @                          .&@@@@           @@  @
               @                   ,(@@@@@&@@@@           @, .@
               @#(/***,*/((%@@@/, /&@@@@@@@@@( *     /      @*
                 ,@*@@@,.@@@@       &@/     %@@@&@@@      */
                 @    #@@@@@      @   @ /@    @@@@@@&      @
                @%        #@      .@(&/    .@@# ,@@%&      &@
                %@ @@@(@@((@     @%@@    @@@ %% ,@%#&      (@
                 @,@* %@@#@           %@@/@  %% .@ /       (@
                  @%    .@@     @@@@@@#   @  &% @@         @
                   @*    @@  @@&&@    #   @  %@@@,        @/
                    @,    ##*     (   @   @@& ,@%        @#
                     @(     (.    %  *@@@/#  &@@        @.
                      %@    (%/   (   (   ##@@@       .@
                        @  .@@@   @   & *@@@@.       #@
                         @( @@@@@@@@@@@@@@@         @&
                          *@  *@@@@@@@(           (@
                            @     *#@%          .@&
                             @/ @     /.       @@
                              @              @@,
                              @@           &@
                              .@@# @.@@#(@@,`
)
