/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage

	Licensees holding valid commercial IoT.bzh licenses may use this file in
	accordance with the commercial license agreement provided with the
	Software or, alternatively, in accordance with the terms contained in
	a written agreement between you and The IoT.bzh Company. For licensing terms
	and conditions see https://www.iot.bzh/terms-conditions. For further
	information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage

	Alternatively, this file may be used under the terms of the GNU General
	Public license version 3. This license is as published by the Free Software
	Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
	of this file. Please review the following information to ensure the GNU
	General Public License requirements will be met
	https://www.gnu.org/licenses/gpl-3.0.html.

$RP_END_LICENSE$
*/
package cmd

import (
	"testing"
	"time"

	"git.ovh.iot/redpesk/redpesk-infra/redpesk-cli/utils"
	"github.com/stretchr/testify/assert"
)

// TestIotPkgWrapper is the function allowing to test if
// the command "rp-cli iotpkg" is working correctly
//
// :param test: Pointer to T testing object
// :type test: *testing.T
func TestIotPkgWrapper(test *testing.T) {
	// Set-up what is needed for redpesk-lad
	setupRPLADTests()
	// Defer the teardown function for redpesk-lad
	defer teardownRPLADTests()

	// Create a false configuration file
	configFilePath, err := createFalseConfigFile()
	if err != nil {
		test.Fatal(err)
	}

	// Delete the false configuration file at the end of the function
	defer deleteFalseFile(configFilePath)

	testFilePath := gitPackagesTestDir + "/iotpkg_test.txt"
	utils.WriteToFile(testFilePath, "Iotpkg test file content")

	time.Sleep(time.Duration(50) * time.Millisecond)

	// Run the commands in a simulated terminal
	cmdOutput, err := execCmdInSimTerm("", "iotpkg", "cat", testFilePath)
	if err != nil {
		// The command returns an error
		test.Fatal(err)
	}

	// Test that the output contains the content of the file
	assert.Equal(test, "Iotpkg test file content\n", cmdOutput)
}
