/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	localCfgSubDirectory         = ".rp-cli"
	localAutogenSubDirectory     = ".redpesk"
	localIotpkgSubDirectory      = ".iotpkg"
	localMD5SUMFile              = "md5sum.json"
	localBldCfgFile              = "local_build_config.json"
	localOriginFilesSubDirectory = "origin-files"

	localLocalBldLogsTag1 = "\nLOCAL-BUILDER LOGS >>>"
	localLocalBldLogsTag2 = "<<< LOCAL-BUILDER LOGS\n"

	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------

	// Main command
	localCommand      = "local"
	localCmdShortDesc = "Local commands group"
	// -------------

	// Execute command
	localExecCmdName       = "exec -- <cmdLine>"
	localExecCmdShortUsage = "Execute a command line in the local-builder"
	localExecCmdLongUsage  = "Execute the command line <cmdLine> in the local-builder"

	localExecCmdWorkingDirFlag      = "working-directory"
	localExecCmdWorkingDirFlagAlias = "w"
	localExecCmdWorkingDirFlagUsage = "Set the working directory, in local-builder, to run the command"
	// -------------

	// Package sub-commands
	localPkgCmdName       = "package"
	localPkgCmdAlias      = "pkg"
	localPkgCmdShortUsage = "Packaging sub-command group"

	localPkgCmdSourceFlag      = "sourcesdir"
	localPkgCmdSourceFlagAlias = "S"
	localPkgCmdSourceFlagUsage = "[Optional] \"gitsources/\" directory path on the host"

	localPkgCmdPackageFlag      = "pkgsdir"
	localPkgCmdPackageFlagAlias = "P"
	localPkgCmdPackageFlagUsage = "[Optional] \"gitpkgs/\" directory path on the host"
	// -------------

	// Package init sub-command
	localPkgInitBranchFlag      = "branch"
	localPkgInitBranchFlagAlias = "b"
	localPkgInitBranchFlagUsage = "[Optional] Specify the package branch to build locally"

	localPkgInitForceFlag      = "force"
	localPkgInitForceFlagAlias = "f"
	localPkgInitForceFlagUsage = "[Optional] Overwrite any already existing gitpkgs/gitsources repository for this application, no check will be done"

	localPkgInitAnsLine0 = "Check 'gitsources' repository status...\t"
	localPkgInitAnsLine1 = "Remove old 'gitsources' repository...\t"
	// -------------

	// Fetch command
	localFetchCmd          = "fetch <app-ID>"
	localFetchCmdShortDesc = "Fetch content from the redpesk factory, create or update a local working directory"
	localFetchCmdLongDesc  = `Fetch content from the redpesk factory, create or update a local working directory.
The content fetch is the application 'gitpkg' repository and the local-builder configuration, mandatory to build locally.
Only one type of content can be downloaded by specifying one optional flag.`

	localFetchCmdGitpkgFlag      = "gitpkg"
	localFetchCmdGitpkgFlagAlias = "g"
	localFetchCmdGitpkgFlagUsage = "[Optional] Download only the 'gitpkg' content"

	localFetchCmdMockCfgFlag      = "local-builder-config"
	localFetchCmdMockCfgFlagAlias = "c"
	localFetchCmdMockCfgFlagUsage = "[Optional] Download only the local builder configuration"

	localFetchCmdForceFlag      = "force"
	localFetchCmdForceFlagAlias = "f"
	localFetchCmdForceFlagUsage = "[Optional] Overwrite any already existing gitpkg repository for this application, no check will be done"

	localFetchCmdAnsLine0 = "\n-- Content fetching requested by user --\n"
	localFetchCmdAnsLine1 = "Retrieve application details...\t"
	localFetchCmdAnsLine2 = "Check local-builder configuration...\t"
	localFetchCmdAnsLine3 = "Create directories if needed...\t"
	localFetchCmdAnsLine4 = "Check 'gitpkg' repository status...\t"
	localFetchCmdAnsLine5 = "Fetch the 'gitpkg' repository from branch '%s'...\t"
	localFetchCmdAnsLine6 = "Fetch local-builder configuration...\t"
	// -------------

	// Status command
	localStatusCmd          = "status <app-ID>"
	localStatusCmdShortDesc = "Show the status of files in the 'gitpkgs/' directory used to local build the application"
	localStatusCmdLongDesc  = `Show the status of files in the 'gitpkgs/' directory used to local build the application.
This command indicates wether files have been modified locally, deleted or added.`

	localStatusCmdAnsLine0 = "\n-- Content status requested by user --\n"
	localStatusCmdAnsLine1 = "Status:"
	localStatusCmdAnsLine2 = "On branch %s\n"

	localStatusAddedFileLine    = "    added:    %s\n"
	localStatusDelFileLine      = "    deleted:  %s\n"
	localStatusModifiedFileLine = "    modified: %s\n"
	localStatusNoChanges        = "    local working directory clean, no changes detected"
	// -------------

	// Diff command
	localDiffCmd          = "diff <app-ID> [files...]"
	localDiffCmdShortDesc = "Files comparison between the local version and the factory version"
	localDiffCmdLongDesc  = `Files comparison between the local version and the factory version.
If no files are specified, rp-cli shows diff of any modified/added/deleted from the working directory.`

	localDiffCmdNoColorFlag      = "no-color"
	localDiffCmdNoColorFlagUsage = "[Optional] Request rp-cli to not display colors in diff"
	// -------------

	// Commit command
	localCommitCmd          = "commit <app-ID> [files...]"
	localCommitCmdShortDesc = "Upload files that have been modified/added/deleted in your working directory, to the remote gitpkg in the redpesk factory"
	localCommitCmdLongDesc  = `Upload files that have been modified/added/deleted in your working directory, to the remote gitpkg in the redpesk factory.
If no files are specified, rp-cli upload any modified/added/deleted from the working directory.`

	localCommitCmdAnsLine0 = "\n-- Commit requested by user --\n"

	localCommitNothingToCommit = "Nothing to commit"
	localCommitUpload          = "Upload of '%s'...\n"
	localCommitRemoval         = "Removal of '%s'...\n"
	// -------------

	// Service command
	localServiceCmd          = "service <app-ID> <service-name>"
	localServiceCmdShortDesc = "Set application service value"

	localServiceCmdAnsLine0 = "\n-- Service change requested by user --\n"

	// Metadata command
	localMetadataCmd          = "metadata <app-ID>"
	localMetadataCmdShortDesc = "Set application metadata value"

	localMetadataCmdAnsLine0 = "\n-- Metadata change requested by user --\n"

	// Package init sub-command
	localPkgInitCmdName       = "init <app-ID>"
	localPkgInitCmdShortUsage = "Initialization needed by the local builder to package"
	localPkgInitCmdLongUsage  = "Initialization needed by the local builder to package the application named <app-ID>"

	localPkgInitCmdAnsLine0 = "\n-- Package initialization requested by user --\n"
	localPkgInitCmdAnsLine1 = "\"gitsources/\" directory used: \t%s\n"
	localPkgInitCmdAnsLine2 = "\"gitpkgs/\" directory used: \t%s\n"
	localPkgInitCmdAnsLine3 = "Retrieving package configuration for \"%s\"\t"
	localPkgInitCmdAnsLine4 = "Setting up the local-builder..."
	localPkgInitCmdAnsLine5 = "Cloning the package sources..."

	// Build command
	localBuildCmd           = "build <app-ID>"
	localBuildCmdShortUsage = "Build locally an application"
	localBuildCmdLongUsage  = "Build locally the application <app-ID>"

	localProjectFlag      = "project"
	localProjectFlagAlias = "p"
	localProjectFlagUsage = "[Optional] Specify the application's parent project slug"

	localBuildArchFlag        = "arch"
	localBuildArchFlagAlias   = "a"
	localBuildArchFlagUsage   = "[Optional] Target architecture"
	localBuildArchFlagDefault = "aarch64"

	localBuildDistroFlag      = "distro"
	localBuildDistroFlagAlias = "d"
	localBuildDistroFlagUsage = "[Optional] Target distribution"

	localBuildOfflineFlag      = "offline"
	localBuildOfflineFlagAlias = "o"
	localBuildOfflineFlagUsage = "[Optional] If set, rp-cli run the build fully offline"

	localBuildRunCmdAnsLine0      = "\n-- Build requested by user --\n"
	localBuildRunCmdAnsLine1      = "Building the application..."
	localBuildRunCmdAnsResultGood = "Congratulations! Your build seems to be successful!"
	localBuildRunCmdAnsResultBad  = "Oops... A wild error appeared while building your application!"
	localBuildRunCmdAnsResultIn   = "Results and/or logs in:"

	// Shell command
	localShellCmd           = "shell <app-ID>"
	localShellCmdShortUsage = "Allow to get a shell inside the mock used to build"
	localShellCmdLongUsage  = "Allow to get a shell inside the mock used to build the app '<app-ID>'"

	localShellCmdAnsLine0 = "\n-- Shell requested by user --\n"

	// Clean command
	localPkgCleanCmdName       = "clean <app-ID>"
	localPkgCleanCmdShortUsage = "Delete all the directories created for local building"
	localPkgCleanCmdLongUsage  = "Delete all the directories created for local building of the application <app-ID>"

	localPkgCleanInitFlag      = "init"
	localPkgCleanInitFlagAlias = "i"
	localPkgCleanInitFlagUsage = "[Optional] If set, rp-cli initializes a new clean directory with configurations found in the previous one"

	localPkgCleanForceFlag      = "force"
	localPkgCleanForceFlagAlias = "f"
	localPkgCleanForceFlagUsage = "[Optional] If set, rp-cli clean directories without checking for sources modification"

	localCleanNoMockFlag      = "no-mock"
	localCleanNoMockFlagAlias = "n"
	localCleanNoMockFlagUsage = "[Optional] If set, the mock directory is not deleted inside the local-builder"

	localPkgCleanCmdAnsLine0 = "-- Package cleaning requested by user --"
	localPkgCleanCmdAnsLine1 = "There are some modifications inside your gitsources. Are you sure you want to delete? (Y/n)"
	localPkgCleanCmdAnsLine2 = "CLEANED"

	// Check-setup command
	localCheckSetupCmd           = "check-setup"
	localCheckSetupCmdShortUsage = "Check that the host is correctly set-up to use the local-builder"

	localCheckSetupCmdAnsLine0 = "\n-- Local check requested by user --\n"
	localCheckSetupCmdAnsLine1 = "Check factory connection...\t"
	localCheckSetupCmdAnsLine2 = "Check local-builder connection...\t"
	localCheckSetupCmdAnsLine3 = "Check local-builder mount-points...\t"
	localCheckSetupCmdAnsLine4 = "Check QEMU set-up...\t"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Events used --------------------------------------------------
	// --------------------------------------------------------------
	localStdOutEvt  = "stdout"
	localStdErrEvt  = "stderr"
	localStdInEvt   = "stdin"
	localProcEndEvt = "process_ended"
	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	// -------------

	// Error messages
	cmdToShortError              = "no command found to run. Format: \"rp-cli local exec -- <cmdline>\""
	stdShouldBeTerminal          = "stdin/stdout should be terminal"
	execErrorMsg                 = "the following error happened while running exec command: %v"
	getTermSizeError             = "an error occured while getting the terminal size: %v"
	webSocketDisconnectionErr    = "the websocket between rp-cli and the local-builder has been disconnected"
	gitPkgNotInstalled           = "please install 'git' package to be able to run the 'rp-cli local package init' command"
	diffUtilsPkgNotInstalled     = "please install 'diffutils' package to be able to run the 'rp-cli local package diff' command"
	filesMustBeAtRootOfGitpkg    = "subdirectories are not authorized in the gitpkg, please move your file '%s' at the gitpkg root"
	packageCleanDirNotFound      = "no directory to clean, path used: '%s'"
	md5sumFileDoesNotExist       = "no md5sum file found for this application"
	cannotFetchWithChanges       = "cannot fetch because you have local changes, please commit or use the --force flag"
	cannotCloneWithChanges       = "cannot clone because you have local changes, please commit or use the --force flag"
	needToSpecifyDistroErr       = "several distributions have been found for the project \"%s\", please specify one with the '-d' flag"
	needToChangeDistroErr        = "the distribution specified (\"%s\") does not exists for this project (\"%s\"), please modify the distribution wanted"
	needToChangeArchErr          = "the architecture specified (\"%s\") does not exists for this project (\"%s\"), please modify the architecture wanted"
	pbOnMountPoints              = "a problem has been seen on the mounted directories '%s' inside the local-builder, either on the directory itself or on the UID/GID"
	varLibBinfmtsFileNotGood     = "the content of /var/lib/binfmts/qemu-aarch64 does not seems good"
	procSysFsBinfmtsFileNotGood  = "the content of /proc/sys/fs/binfmt_misc/qemu-aarch64 does not seem good, please try to follow the steps available here: https://docs.redpesk.bzh/docs/en/master/redpesk-factory/local_builder/docs/4_advanced-installation.html#setup-your-host-for-local-crossbuild"
	rootBuildDirDoesntExist      = "the directory '%s', given as build directory does not exist in the local-builder"
	noAppSpecifiedAndNotInDir    = "rp-cli is not able to find the right application: no application slug is specified and you are not in a valid local-builder directory"
	appIdentifierNotFoundLocally = "no application has been found locally with the slug \"%s\""
	noLocalCfgForThisAppAndPrj   = "no local configuration has been found for this application and project"
	// -------------

	// Warning messages
	localCleanNoSourcesDirWarn = "No directory found for sources of app '%s'"
	noGitSourceFoundWarn       = "The source directory may not be a git repository, error: '%v'"
	ignoreFilesInSubDir        = "Ignoring '%s': files cannot be in sub-directories"
	// -------------

	// Debug messages
	endOfProc = "End of process %s with status %d"
	// -------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Files content for diagnosis ----------------------------------
	// --------------------------------------------------------------
	varLibBinfmtsQemuAarch64 = `qemu-user-static
magic
0
\x7f\x45\x4c\x46\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\xb7\x00
\xff\xff\xff\xff\xff\xff\xff\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff
/usr/bin/qemu-aarch64-static`

	procSysFsBinfmtMiscQemuAarch64V0 = `enabled
interpreter /usr/bin/qemu-aarch64-static
flags: F
offset 0
magic 7f454c460201010000000000000000000200b700
mask ffffffffffffff00fffffffffffffffffeffffff`

	procSysFsBinfmtMiscQemuAarch64V1 = `enabled
interpreter /usr/bin/qemu-aarch64-static
flags: OCF
offset 0
magic 7f454c460201010000000000000000000200b700
mask ffffffffffffff00fffffffffffffffffeffffff`

	procSysFsBinfmtMiscQemuAarch64V2 = `enabled
interpreter /usr/libexec/qemu-binfmt/aarch64-binfmt-P
flags: POCF
offset 0
magic 7f454c460201010000000000000000000200b700
mask ffffffffffffff00fffffffffffffffffeffffff`

	fixVarLibBinfmtsQemuAarch64file = `sudo cat << EOF | sudo tee /var/lib/binfmts/qemu-aarch64
 qemu-user-static
 magic
 0
 \x7f\x45\x4c\x46\x02\x01\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\xb7\x00
 \xff\xff\xff\xff\xff\xff\xff\x00\xff\xff\xff\xff\xff\xff\xff\xff\xfe\xff\xff\xff
 /usr/bin/qemu-aarch64-static



 yes
 EOF`

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)

// Type used for local builder events
type RPLocalBuilderEvent struct {
	ID     string `json:"id"`
	Line   string `json:"std_line"`
	Status int    `json:"status"`
	Type   string `json:"type"`
}

// Type used to send stdin event to local builder
type RPLocalBStdinEvent struct {
	ID    string `json:"id"`
	Chars string `json:"stdin_chars"`
}

// Type used to notify the end of interactive command
type RPLocalExitResult struct {
	Error error
	Code  int
}

// Type used to store information about gitpkg files modifications
type RPLocalGitpkgsModification struct {
	Added    []string
	Modified []string
	Deleted  []string
}

// Structure used to contain all the data necessary to
// set the local builder for build
type RPLocalBuildConfig struct {
	SourcesDir  string   `json:"sources_dir"`
	PackagesDir string   `json:"packages_dir"`
	Branch      string   `json:"branch"`
	AppPkgName  string   `json:"app_pkg_name"`
	AppSlug     string   `json:"app_slug"`
	ProjectSlug string   `json:"project_slug"`
	DistrosList []string `json:"distros_list"`
	ArchsList   []string `json:"archs_list"`
}
