/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (

	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------

	// projects commands
	prjsCommand           = "projects"
	prjsCommandAlias      = "prj"
	prjsCommandShortUsage = "Projects commands group"

	// List command
	prjsListCmd                      = "list"
	prjsListCmdAlias                 = "ls"
	prjsListCmdShortUsage            = "List the projects from the Redpesk infrastructure"
	prjsListCmdBookmarkedFlag        = "bookmarked"
	prjsListCmdBookmarkedFlagAlias   = "b"
	prjsListCmdBookmarkedFlagDefault = false
	prjsListCmdBookmarkedFlagUsage   = "Display only the bookmarked projects"
	prjsListCmdTypeFlag              = "type"
	prjsListCmdTypeFlagUsage         = "Specify the type of projects to display"
	prjsListCmdHeader                = "ID\t Slug\t Name\t Version\t Type"
	prjsListCmdVerboseLine0          = "ID:\t"
	prjsListCmdVerboseLine1          = "Name:\t"
	prjsListCmdVerboseLine2          = "Creation time:\t"
	prjsListCmdVerboseLine3          = "Update time:\t"
	prjsListCmdVerboseLine4          = "Distributions:\t"
	prjsListCmdVerboseLine5          = "Architectures:\t"
	prjsListCmdVerboseLine6          = "Slug:\t"
	prjsListCmdVerboseLine7          = "Inherits from:\t"
	prjInheritanceStr                = "%s [Priority: %d]"
	prjsListCmdVerboseLine8          = "Description:\t"
	prjsListCmdVerboseLine9          = "Bookmarked:\t"
	prjsListCmdVerboseLine10         = "Type:\t"
	prjsListCmdVerboseLine11         = "Version:\t"
	prjsListCmdVerboseLine12         = "Short release naming:\t"
	prjsListCmdVerboseLine14         = "Supported Objects:\t"
	prjsListCmdVerboseLine15         = "Access token(s):\t"
	prjsListCmdVerboseLine16         = "SubVersion:\t"

	projectDisplayVerboseLightLineNb = 14

	// Get command
	prjsGetCmd              = "get <project-ID>"
	prjsGetCmdShortUsage    = "Get the properties of a project"
	prjsGetCmdRepoFlag      = "repository"
	prjsGetCmdRepoFlagAlias = "r"
	prjsGetCmdRepoFlagUsage = "Request to display the repository file for the given project"
	prjsGetCmdAnsLine0      = "Add repository on target:"
	prjsGetCmdAnsLineDash   = "-------------------------"
	prjsGetCmdAnsRepoURL    = "Repository URL:"
	prjsGetCmdRoleFlag      = "roles"
	prjsGetCmdRoleFlagUsage = "Request to display the list of available roles for the given project"
	prjsGetCmdAnsLine1      = "Available roles:"
	prjsGetCmdAnsLine2      = "Role\t Description"

	prjsAddCmd           = "add"
	prjsAddAlias         = "a"
	prjsAddCmdShortUsage = "Create a new project"

	prjsAddCmdMandArchFlag      = "mandatory-arch"
	prjsAddCmdMandArchFlagUsage = "Flag to use to specify a mandatory architecture, this flag can be used several times"

	prjsAddCmdOptArchFlag      = "optional-arch"
	prjsAddCmdOptArchFlagUsage = "Flag to use to specify an optional architecture, this flag can be used several times"

	prjsAddCmdMandDistFlag      = "mandatory-distro"
	prjsAddCmdMandDistFlagUsage = "Flag to use to specify a mandatory distribution, this flag can be used several times"

	prjsAddCmdOptDistFlag      = "optional-distro"
	prjsAddCmdOptDistFlagUsage = "Flag to use to specify an optional distribution, this flag can be used several times"

	prjsAddCmdNameFlag      = "name"
	prjsAddCmdNameFlagAlias = "n"
	prjsAddCmdNameFlagUsage = "[Mandatory] Name of the project to create"

	prjsAddCmdAliasFlag      = "alias"
	prjsAddCmdAliasFlagAlias = "a"
	prjsAddCmdAliasFlagUsage = "[Optional] Alias for the project name (must be unique)"

	prjsAddCmdShortReleaseFlag        = "short-release-name"
	prjsAddCmdShortReleaseFlagDefault = false
	prjsAddCmdShortReleaseFlagUsage   = "[Optional] use short release name in final packages of this project"

	prjsAddCmdDescFlag      = "description"
	prjsAddCmdDescFlagAlias = "d"
	prjsAddCmdDescFlagUsage = "[Optional] Description of the project to create"

	prjsAddCmdInheritFlag      = "inherit"
	prjsAddCmdInheritFlagAlias = "i"
	prjsAddCmdInheritFlagUsage = "[Optional] Set a parent for the current project, this flag can be used several times"

	prjsAddCmdAppSupportFlag        = "applications"
	prjsAddCmdAppSupportFlagDefault = false
	prjsAddCmdAppSupportFlagUsage   = "[Optional] Enable the support of application objects in project"

	prjsAddCmdImgSupportFlag        = "images"
	prjsAddCmdImgSupportFlagDefault = false
	prjsAddCmdImgSupportFlagUsage   = "[Optional] Enable the support of image objects in project"

	prjsAddCmdCtnSupportFlag        = "containers"
	prjsAddCmdCtnSupportFlagDefault = false
	prjsAddCmdCtnSupportFlagUsage   = "[Optional] Enable the support of container objects in project"

	prjsAddCmdAnsLine0 = "-- Project creation requested by user --"
	prjsAddCmdAnsLine1 = "Checking that at least one architecture is set...\t"
	prjsAddCmdAnsLine2 = "Checking that at least one distribution is set...\t"
	prjsAddCmdAnsLine3 = "Creation of \"%s\" project...\t"

	// Update command
	prjsUpdateCmd           = "update <project-ID>"
	prjsUpdateAlias         = "upd"
	prjsUpdateCmdShortUsage = "Update a project settings"
	prjsUpdateCmdLongUsage  = "Update a project settings, all the parameters not set in the command line will be retrieved from the current project and kept intact"
	prjsUpdateCmdAnsLine0   = "-- Project update requested by user --"
	prjsUpdateCmdAnsLine1   = "Update of \"%s\" project...\t"
	prjsUpdateCmdAnsLine2   = "Modification of project app(s) build type for \"%s\"...\t"

	prjsForceStateFlag      = "force-stable-state"
	prjsForceStateFlagUsage = "[Hidden] Set to true to force project's state to \"stable\""

	prjsUpdateCmdBldTypeFlag      = "build-type"
	prjsUpdateCmdBldTypeFlagAlias = "t"
	prjsUpdateCmdBldTypeFlagUsage = "[Optional] Set the build type for the project apps (all of them or only the ones specified with the 'bld-type-apps' flag)"

	prjsUpdateCmdBldTypeAppsFlag      = "bld-type-apps"
	prjsUpdateCmdBldTypeAppsFlagUsage = "[Optional] Specify a comma separated list of apps where the build type needs to be changed"

	prjsUpdateCmdSubVersionFlag      = "sub-version"
	prjsUpdateCmdSubVersionFlagUsage = "[Optional] SubVersion of the project"

	// Delete command
	prjsDelCmd           = "delete <project-ID>"
	prjsDelAlias         = "del"
	prjsDelCmdShortUsage = "Delete a project"
	prjsDelCmdAnsLine0   = "-- Project deletion requested by user --"
	prjsDelCmdAnsLine1   = "Deletion of \"%s\" project...\t"

	// Bookmark command
	prjsBookmarkCmd               = "bookmark <project-ID>"
	prjsBookmarkAlias             = "bmark"
	prjsBookmarkCmdShortUsage     = "Bookmark a project"
	prjsBookmarkCmdResetFlag      = "reset"
	prjsBookmarkCmdResetFlagAlias = "r"
	prjsBookmarkCmdResetFlagUsage = "Delete the project's bookmark"
	prjsBookmarkCmdAnsLine0       = "-- Project bookmarking requested by user --"
	prjsBookmarkCmdAnsLine1       = "Bookmarking of \"%s\" project...\t"
	prjsBookmarkCmdAnsLine2       = "Deletion of \"%s\" project's bookmark...\t"
	prjsBookmarkCmdAnsLine3       = "\"%s\" project is not bookmarked, nothing to do...\t"
	prjsBookmarkCmdAnsLine4       = "\"%s\" project is already bookmarked, nothing to do...\t"

	// Project's member subcommand
	prjMembersCmd           = "members <subcommand>"
	prjMembersCmdShortUsage = "Projects members sub-commands group"

	// Get member subcommand
	prjMembersGetCmd           = "get <project-ID>"
	prjMembersGetCmdShortUsage = "List the members of a project"
	prjMembersGetCmdAnsLine0   = ""
	prjMembersGetCmdAnsLine1   = "Member ID:\t"
	prjMembersGetCmdAnsLine2   = "Pseudo:\t"
	prjMembersGetCmdAnsLine3   = "Role(s):\t"
	prjMembersGetCmdHeader     = "Pseudo\t Roles"

	// Add subcommand
	prjMembersAddCmd           = "add <project-ID> --guest=<user-ID> --role=<role>"
	prjMembersAddCmdShortUsage = "Add a user as member of a project"
	prjMembersAddCmdLongUsage  = "Add the user <user-ID> as member of the project <project-ID> and with the role(s) <role>"

	prjsMembersAddCmdGuestFlag  = "guest"
	prjsMembersAddCmdGuestAlias = "g"
	prjsMembersAddCmdGuestUsage = "[Mandatory] Guest user to add to the project"

	prjsMembersAddCmdRoleFlag  = "role"
	prjsMembersAddCmdRoleAlias = "r"
	prjsMembersAddCmdRoleUsage = "[Mandatory] Role to give to the user that will be added. This flag can be set several times, if several roles are needed"

	prjsMembersAddCmdAnsLine0 = "-- Addition of a member in a project requested by user --"
	prjsMembersAddCmdAnsLine1 = "Addition of the member \"%s\", with the role(s) \"%s\" in the project \"%s\"...\t"

	// Update subcommand
	prjMembersUpdateCmd           = "update <project-ID> --member=<user-ID> --role=<role>"
	prjMembersUpdateCmdShortUsage = "Update a project member's roles"
	prjMembersUpdateCmdLongUsage  = "Change the roles of the member <user-ID> in the project <project-ID> with the new role(s) <role>"

	prjsMembersUpdateCmdMemberFlag  = "member"
	prjsMembersUpdateCmdMemberAlias = "m"
	prjsMembersUpdateCmdMemberUsage = "[Mandatory] Member's ID needing a roles update"

	prjsMembersUpdateCmdRoleUsage = "[Mandatory] New roles to give to the specified member. This flag can be set several times, if several roles are needed"

	prjsMembersUpdateCmdAnsLine0 = "-- Modification of member roles in a project requested by user --"
	prjsMembersUpdateCmdAnsLine1 = "Modification of the member \"%s\", with the role(s) \"%s\" in the project \"%s\"...\t"

	// Delete subcommand
	prjMembersDeleteCmd           = "delete <project-ID> --member=<user-ID>"
	prjMembersDeleteCmdShortUsage = "Delete a member of a project"
	prjMembersDeleteCmdLongUsage  = "Delete the member <user-ID> from the project <project-ID>"

	prjsMembersDeleteCmdMemberUsage = "[Mandatory] Member's ID to be deleted from the project"

	prjsMembersDeleteCmdAnsLine0 = "-- Deletion of member from a project requested by user --"
	prjsMembersDeleteCmdAnsLine1 = "Deletion of the member \"%s\", from the project \"%s\"...\t"

	// Export subcommand
	prjsExportCmd           = "export"
	prjsExportCmdShortUsage = "Projects export sub-commands group"

	// Export start subcommand
	prjsExportStartCmd           = "start <project-ID>"
	prjsExportStartCmdShortUsage = "Start the export of the specified project"
	prjsExportStartCmdLongUsage  = `Start the export of the specified project.
By default, the command waits for the project export to be correctly completed and then download the created archive.
If you don't want to wait, use the '--nonblocking' flag.`

	prjsExportStartCmdAnsLine0  = "-- Project export requested by user --"
	prjsExportStartCmdAnsLine1  = "Requesting export of project \"%s\"...\t"
	prjsExportStartCmdAnsLine2  = "Waiting for export to be complete...\t"
	prjsExportStartCmdAnsLine3  = "Downloading the archive...\t"
	prjsExportStartCmdAnsLine4  = "Path to the exported project archive: %s\n"
	prjsExportStartCmdAnsLine5  = "Project ID:\t"
	prjsExportStartCmdAnsLine6  = "Start date:\t"
	prjsExportStartCmdAnsLine7  = "End date:\t"
	prjsExportStartCmdAnsLine8  = "Status:\t"
	prjsExportStartCmdAnsLine9  = "Elapsed at:\t"
	prjsExportStartCmdAnsLine10 = "Error:\t"

	prjsExportCmdDirFlag        = "dir"
	prjsExportCmdDirFlagAlias   = "d"
	prjsExportCmdDirFlagUsage   = "[Optional] Directory to use to store the archive of the exported project"
	prjsExportCmdDirFlagDefault = "./"

	// Export get subcommand
	prjsExportImportGetCmd     = "get <project-ID>"
	prjsExportGetCmdShortUsage = "Display the current export status"

	// Export download subcommand
	prjsExportDownloadCmd           = "download <project-ID>"
	prjsExportDownloadCmdShortUsage = "Download manually the export archive to the specified directory"

	prjsExportDownloadCmdAnsLine0 = "-- Archive download requested by user --"

	// Import subcommand
	prjsImportCmd           = "import"
	prjsImportCmdShortUsage = "Projects import sub-commands group"

	// Import start command
	prjsImportStartCmd           = "start"
	prjsImportStartCmdShortUsage = "Upload the project archive and start to import it"
	prjsImportStartCmdLongUsage  = `Upload the project archive and start to import it.
By default, the command waits for the project import to be correctly completed to exit.
If you don't want to wait, use the '--nonblocking' flag.`

	prjsImportCmdFileFlag      = "file"
	prjsImportCmdFileFlagAlias = "f"
	prjsImportCmdFileFlagUsage = "[Mandatory] Project archive file to upload"

	prjsImportCmdInteractiveFlag      = "interactive"
	prjsImportCmdInteractiveFlagAlias = "i"
	prjsImportCmdInteractiveFlagUsage = "[Optional] Enable the interactive import of the project"

	prjsImportStartCmdAnsLine0 = "-- Project import requested by user --"
	prjsImportStartCmdAnsLine1 = "Uploading the project archive...\t"
	prjsImportStartCmdAnsLine2 = "Requesting for project import...\t"
	prjsImportStartCmdAnsLine3 = "Waiting for import to be complete...\t"
	prjsImportStartCmdAnsLine4 = "Please hit \"Enter\" to request the project import on the factory..."

	// Import get subcommand
	prjsImportGetCmdShortUsage = "Display the current import status"

	// Release subcommand
	prjsReleaseCmd        = "release <prj-ID>"
	prjsReleaseCmdAlias   = "rls"
	prjsReleaseShortUsage = "Release a project on the factory"
	prjsReleaseLongUsage  = `Release a project on the factory.
The release can be done only for the current members or for a larger audience.
If you want to define another audience, use the '--team', '--user' or '--all-users' flags.`
	prjsReleaseCmdAnsLine0 = "-- Project release requested by user --"
	prjsReleaseCmdAnsLine1 = "Checking distribution validity...\t"
	prjsReleaseCmdAnsLine2 = "Requesting the factory to release the project \"%s\"...\t"
	prjsReleaseCmdAnsLine3 = "Waiting for the project \"%s\" to be released...\t"
	prjsReleaseCmdAnsLine4 = "Modifying the audience of \"%s\" project...\t"

	prjsReleaseCmdNameFlag      = "name"
	prjsReleaseCmdNameFlagAlias = "n"
	prjsReleaseCmdNameFlagUsage = "[Optional] Project release name"

	prjsReleaseCmdDescFlagUsage = "[Optional] Description of the project release"

	prjsReleaseCmdDistroFlag      = "distribution"
	prjsReleaseCmdDistroFlagUsage = "[Mandatory] Targeted distribution for the release"

	prjsReleaseCmdVersionFlag      = "version"
	prjsReleaseCmdVersionFlagAlias = "v"
	prjsReleaseCmdVersionFlagUsage = "[Mandatory] Version of the release"

	prjsReleaseCmdTeamFlag      = "team"
	prjsReleaseCmdTeamFlagUsage = "[Optional] Team(s) to add to the release audience"

	prjsReleaseCmdUserFlag      = "user"
	prjsReleaseCmdUserFlagAlias = "u"
	prjsReleaseCmdUserFlagUsage = "[Optional] User(s) to add to the release audience"

	prjsReleaseCmdAllUsersFlag      = "all-users"
	prjsReleaseCmdAllUsersFlagAlias = "a"
	prjsReleaseCmdAllUsersFlagUsage = "[Optional] Set this flag to release the project for all the members of the factory"

	// Releases subcommand
	prjsReleasesCmd           = "releases"
	prjsReleasesCmdShortUsage = "Projects releases sub-commands group"

	// List subcommand of released project
	prjsListReleasedCmdShortUsage = "List the released projects from the infrastructure"

	projectRelDisplayVerboseLightLineNb = 11

	prjsListReleasedCmdHeader = "ID\t Slug\t Version\t Reference"

	// Get subcommand on released project
	prjsGetReleasedCmdShortUsage = "Get the properties of a released project"

	prjsGetReleaseCmdAudienceFlag      = "audience"
	prjsGetReleaseCmdAudienceFlagAlias = "a"
	prjsGetReleaseCmdAudienceFlagUsage = "[Optional] Set this flag to display the audience of the released project"

	prjsGetReleasedCmdVerboseLine0  = "Reference project ID:\t"
	prjsGetReleasedCmdVerboseLine1  = "Reference project slug:\t"
	prjsGetReleasedCmdVerboseLine2  = "Distribution ID:\t"
	prjsGetReleasedCmdVerboseLine3  = "[Released applications]"
	prjsGetReleasedCmdVerboseLine4  = "Application ID:\t"
	prjsGetReleasedCmdVerboseLine5  = "Package name:\t"
	prjsGetReleasedCmdVerboseLine6  = "SHA Gitpkg:\t"
	prjsGetReleasedCmdVerboseLine7  = "Branch:\t"
	prjsGetReleasedCmdVerboseLine8  = "Build ID:\t"
	prjsGetReleasedCmdVerboseLine9  = "[Detailed info]"
	prjsGetReleasedCmdVerboseLine10 = "[Audience]"
	prjsGetReleasedCmdVerboseLine11 = "All Users:\t"
	prjsGetReleasedCmdVerboseLine12 = "Team(s):\t"
	prjsGetReleasedCmdVerboseLine13 = "User(s):\t"

	// Update subcommand on released project
	prjsUpdateReleasedCmdShortUsage = "Update a released project settings (info and audience)"

	prjsUpdateReleaseCmdResetUsersFlag      = "reset-users"
	prjsUpdateReleaseCmdResetUsersFlagUsage = "[Optional] Set this flag to reset all the users in the audience of the released projects"

	prjsUpdateReleaseCmdResetTeamsFlag      = "reset-teams"
	prjsUpdateReleaseCmdResetTeamsFlagUsage = "[Optional] Set this flag to reset all the teams in the audience of the released projects"

	prjsReleaseUpdateCmdAnsLine0 = "-- Released project update requested by user --"
	prjsReleaseUpdateCmdAnsLine1 = "Requesting the factory to update the project \"%s\"...\t"
	prjsReleaseUpdateCmdAnsLine2 = "Modifying the audience of \"%s\" project...\t"

	// Delete subcommand on released project
	prjsDeleteReleasedCmdShortUsage = "Delete a released project"

	prjsDeleteReleaseCmdAnsLine0 = "-- Released project deletion requested by user --"
	prjsDeleteReleaseCmdAnsLine1 = "Requesting the factory to delete the project \"%s\"...\t"

	// Deploy subcommand on released project
	prjsDeployReleaseCmd        = "deploy <rel-prj-ID>"
	prjsDeployReleaseCmdAlias   = "dpl"
	prjsDeployReleaseShortUsage = "Deploy a released project on one or several boards"
	prjsDeployReleaseLongUsage  = `Deploy a released project on one or several boards.
If the deployment is done on several boards, they have to be part of the same board model.`

	prjsDeployReleaseCmdAnsLine0 = "-- Released project deployment requested by user --"
	prjsDeployReleaseCmdAnsLine1 = "Requesting the factory to deploy the project \"%s\"...\t"
	prjsDeployReleaseCmdAnsLine2 = "Deployment of \"%s\" in progress, waiting for the end...\t"

	prjsDeployReleaseCmdBoardsFlag      = "boards"
	prjsDeployReleaseCmdBoardsFlagAlias = "b"
	prjsDeployReleaseCmdBoardsFlagUsage = "[Optional] List of boards where the project needs to be deployed (comma separated list or the flag can be used several times)"

	// Build command group
	prjsBuildCmd           = "build"
	prjsBuildCmdShortUsage = "Group of subcommands to build a project objects (apps, images or all)"

	// Build apps command
	prjsBuildAppsCmd           = "applications <prj-ID>"
	prjsBuildAppsCmdAlias      = "apps"
	prjsBuildAppsCmdShortUsage = "Start building the project's apps on the redpesk factory"
	prjsBuildAppsCmdLongUsage  = `Start building the project's apps on the redpesk factory.
The applications to build and the distributions can be specified through the available options.`

	// Build images command
	prjsBuildImagesCmd           = "images <prj-ID>"
	prjsBuildImagesCmdAlias      = "imgs"
	prjsBuildImagesCmdShortUsage = "Start building the project's images on the redpesk factory"
	prjsBuildImagesCmdLongUsage  = `Start building the project's images on the redpesk factory.
The images to build can be specified through the '-i' option.`

	// Build all objects command
	prjsBuildAllCmd           = "all <prj-ID>"
	prjsBuildAllCmdShortUsage = "Start building all the project's objects on the redpesk factory"
	prjsBuildAllCmdLongUsage  = `Start building all the project's objects on the redpesk factory.
First, the applications are built and then, the images.`

	// Builds command group
	prjsBuildsCmd           = "builds"
	prjsBuildsCmdShortUsage = "Group of subcommands relative to \"builds\" of a project"

	// Builds stats command
	prjsSubBuildsStatsCmd           = "stats <prj-ID>"
	prjsSubBuildsStatsAlias         = "sts"
	prjsSubBuildsStatsCmdShortUsage = "Display build statistics of the given project"

	prjsSubBuildsStatsCmdAnsLine0      = "Project ID:\t"
	prjsSubBuildsStatsCmdAnsLine1      = "Done:\t"
	prjsSubBuildsStatsCmdAnsLine2      = "Failed:\t"
	prjsSubBuildsStatsCmdAnsLine3      = "Cancelled:\t"
	prjsSubBuildsStatsCmdAnsLine4      = "Total:\t"
	prjsSubBuildsStatsCmdAnsLine5      = "[Applications stats]"
	prjsSubBuildsStatsCmdAnsAppsHeader = "ID\t Slug\t Package\t Done\t Failed\t Cancelled\t Total"

	// Builds matrix command
	prjsSubBuildsMatrixCmd           = "matrix <prj-ID>"
	prjsSubBuildsMatrixAlias         = "mtx"
	prjsSubBuildsMatrixCmdShortUsage = "Display a matrix of builds per application and per distribution"
	prjsSubBuildsMatrixCmdAnsHeader  = "Application\t %s\n"

	prjsSubBuildsMatrixFailOnlyFlag      = "fail-only"
	prjsSubBuildsMatrixFailOnlyFlagAlias = "f"
	prjsSubBuildsMatrixFailOnlyFlagUsage = "Display only the failed last builds for a project"

	// Tests command group
	prjsTestsCmd           = "tests"
	prjsTestsCmdShortUsage = "Group of subcommands relative to \"tests\" of a project"

	// Tests stats command
	prjsTestsStatsCmdAnsLine0      = "Project ID:\t"
	prjsTestsStatsCmdAnsLine1      = "Succeeded:\t"
	prjsTestsStatsCmdAnsLine2      = "Failed:\t"
	prjsTestsStatsCmdAnsLine3      = "Cancelled:\t"
	prjsTestsStatsCmdAnsLine4      = "Total:\t"
	prjsTestsStatsCmdAnsLine5      = "[Applications stats]"
	prjsTestsStatsCmdAnsLine6      = "[Images stats]"
	prjsTestsStatsCmdAnsAppsHeader = "ID\t Slug\t Package\t Succeeded\t Failed\t Cancelled\t Total"
	prjsTestsStatsCmdAnsImgsHeader = "ID\t Slug\t Succeeded\t Failed\t Cancelled\t Total"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Error messages
	prjNameFlagNotSetShortMsg         = "Empty name for project during creation"
	prjNameFlagNotSetLongMsg          = "please provide a name for your project"
	prjIDNotSetMsg                    = "No project ID argument in the command line"
	prjIDRequiredMsg                  = "A project ID is required for the wanted operation, please provide one"
	prjGuestNotSetMsg                 = "No guest flag in the command line"
	prjGuestRequiredMsg               = "a valid guest is required for the wanted operation, please provide one"
	prjMemberNotSetMsg                = "No member flag in the command line"
	prjMemberRequiredMsg              = "a valid member is required for the wanted operation, please provide one"
	prjRoleNotSetMsg                  = "No role flag in the command line"
	prjRoleRequiredMsg                = "a valid role is required for the wanted operation, please provide one"
	prjArchNotSetShortMsg             = "No architecture has been specified, at least one is needed"
	prjArchNotSetLongMsg              = "please provide at least one architecture for the project with \"--mandatory-arch\" or \"--optional-arch\" flag"
	prjDistNotSetShortMsg             = "No distribution has been specified, at least one is needed"
	prjDistNotSetLongMsg              = "please provide at least one distribution for the project with \"--mandatory-distro\" or \"--optional-distro\" flag"
	prjPartialDistArchInheritShortMsg = "Architecture and distributions partially provided"
	prjPartialDistArchInheritLongMsg  = "when using inheritance, provide all the architectures and distributions wanted or none; in this last case, the parent project settings are used"
	prjIdentifierNotFound             = "no project has been clearly identified with \"%s\", check out the previous warning messages that may give you an explanation"
	prjIdentifierNotFoundOnTryX       = "the project identifier '%s' has not been found on attempt #%d (filter: '%s')"
	tooManyPrjIDFoundOnTryX           = "too many project identifiers have been found on attempt #%d (filter: '%s'). Please try to use the slug/alias instead of the project name"
	prjGuestIdentifierNotFound        = "no guest has been found with the identifier \"%s\""
	prjMemberIdentifierNotFound       = "no member has been found with the identifier \"%s\""
	prjRoleIdentifierNotFound         = "no role has been found with the identifier \"%s\""
	prjInheritCheckFailDistMsg        = "Distribution %s cannot be used in project since it is not available in the parent"
	prjInheritCheckFailArchMsg        = "Architecture %s cannot be used in project since it is not available in the parent"
	prjBookmarkNotChangedMsg          = "A problem occurred when setting/resetting the bookmark, it has not be taken into account"
	prjImportFileNotExisting          = "the file '%s' does not exists on the machine"
	prjGetReleasedErrorMsg            = "displaying a released project is not supported by this command, please use the following command: 'rp-cli project releases get %s'"
	prjRelAudienceNotAvailableMsg     = "the user/team with UUID '%s' is not available for release audience"
	prjRelRoleNotAvailableMsg         = "the role '%s' is not available for the user/team with UUID '%s'"
	prjRelDeployNoBoardsSpecified     = "no board has been given by the user for the deployment, at least one is needed"
	prjAppToBuildNotInProjectMsg      = "the application '%s' does not exist in the project '%s'"
	prjImageToBuildNotInProjectMsg    = "the image '%s' does not exist in the project '%s'"
	// ----------------------

	// Warning messages
	prjInheritanceMoreThanOne = "[WARNING] Inheriting from more than one project is planned to be supported, but not ready yet. Enabling it can be done at your own risk"
	// ----------------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
