/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------
	// users command
	usersCommand      = "users"
	usersCmdShortDesc = "Users commands group"
	// -------------

	// List command
	usersListCmdName         = "list"
	usersListCmdAlias        = "ls"
	usersListCmdShortUsage   = "List the users from the Redpesk infrastructure"
	usersListCmdHeader       = "Pseudo\t Firstname\t Lastname"
	usersListCmdVerboseLine0 = "ID:\t"
	usersListCmdVerboseLine1 = "Email:\t"
	usersListCmdVerboseLine2 = "Firstname:\t"
	usersListCmdVerboseLine3 = "Lastname:\t"
	usersListCmdVerboseLine4 = "Phone:\t"
	usersListCmdVerboseLine5 = "Disabled:\t"
	usersListCmdVerboseLine6 = "Pseudo:\t"

	userDisplayVerboseLineNb = 7
	// -------------

	// Get command
	userGetCmdName       = "get <user-ID>"
	userGetCmdShortUsage = "Get the properties of a user"
	userGetCmdLongUsage  = "Get the properties of the user <user-ID>, if he is equal to \"me\", the get is done on the current user"
	// -------------

	// Add command
	userAddCmdName       = "add"
	userAddCmdShortUsage = "Create a new user"

	userAddCmdAnsLine0 = "------ User creation requested by user -----"
	userAddCmdAnsLine1 = "Creation of \"%s\" user...\t"

	userAddCmdPseudoFlag      = "pseudo"
	userAddCmdPseudoFlagAlias = "p"
	userAddCmdPseudoFlagUsage = "[Mandatory] Pseudo of the new user"

	userAddCmdMailFlag      = "email"
	userAddCmdMailFlagAlias = "e"
	userAddCmdMailFlagUsage = "[Mandatory] Email of the new user"

	userAddCmdFNameFlag      = "firstname"
	userAddCmdFNameFlagAlias = "f"
	userAddCmdFNameFlagUsage = "[Optional] Firstname of the new user"

	userAddCmdLNameFlag      = "lastname"
	userAddCmdLNameFlagAlias = "n"
	userAddCmdLNameFlagUsage = "[Optional] Lastname of the new user"

	userAddCmdPhoneFlag      = "phone"
	userAddCmdPhoneFlagUsage = "[Optional] Phone number of the new user"
	// -------------

	// Update command
	userUpdateCmdName       = "update <user-ID>"
	userUpdateCmdAlias      = "upd"
	userUpdateCmdShortUsage = "Update a user settings"
	userUpdateCmdLongUsage  = "Update the settings of user <user-ID>, if he is equal to \"me\", the update is done on the current user"

	userUpdCmdAnsLine0 = "------ User update requested by user -----"
	userUpdCmdAnsLine1 = "Update of \"%s\" user...\t"
	// -------------

	// Disable command
	userDisableCmdName       = "disable <user-ID>"
	userDisableCmdAlias      = "dsb"
	userDisableCmdShortUsage = "Disable a user"
	userDisableCmdLongUsage  = "Disable the user <user-ID> if he is not already disabled"

	userDsbCmdAnsLine0 = "------ User disabling requested by user -----"
	userDsbCmdAnsLine1 = "Checking that the user \"%s\" is enabled... \t"
	userDsbCmdAnsLine2 = "Disabling of \"%s\" user...\t"
	// -------------

	// Enable command
	userEnableCmdName       = "enable <user-ID>"
	userEnableCmdAlias      = "enb"
	userEnableCmdShortUsage = "Enable a user"
	userEnableCmdLongUsage  = "Enable the user <user-ID> if he is not already enabled"

	userEnbCmdAnsLine0 = "------ User enabling requested by user -----"
	userEnbCmdAnsLine1 = "Checking that the user \"%s\" is disabled... \t"
	userEnbCmdAnsLine2 = "Enabling of \"%s\" user...\t"
	// -------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	userCreationInfoMsg = "Asking for the creation of the user: \"%s\""
	userUpdateInfoMsg   = "Asking for the update of the user: \"%s\""

	// Error messages
	userIDNotSetMsg       = "No user ID argument in the command line"
	userIDRequiredMsg     = "A user ID is required for the requested operation, please provide one"
	userNotFoundMsg       = "user not found. Either the user does not exist or you are not allowed to access it"
	userTypeNotRecognized = "an internal error occurred: the user type is not recognized"

	userCurrentNotAdmin    = "This operation is available for admin users only"
	userCurrentNotAdminMsg = "you are trying to execute an administrator's operation when you are not admin: operation aborted"

	userUpdateOnlyMeMsg = "you are trying to update another profile than yours, this is not supported for the moment"

	userIdentifierNotFound = "no user has been found with the identifier \"%s\""

	userAlreadyDisabledMsg = "the user that you are trying to disable is already disabled"
	userAlreadyEnabledMsg  = "the user that you are trying to enable is already enabled"

	// Debug messages
	userCreationDebugMsg = "Asking for the creation of the user: %+v"
	userUpdateDebugMsg   = "Asking for the update of the user: %+v"

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
