#
# spec file for package rp-cli
#

%global project         redpesk
%global repo            redpesk-cli
%global debug_package   %{nil}
%global _binary         rp-cli
%global _binary_alias   rpcli
%global _prompt         rp-cli-prompt

Name:           redpesk-cli
Version:        1.0.0
Release:        0
License:        GPL-3.0-or-later AND RedPesk-Proprietary
Group:          Development/Tools/Debuggers
Summary:        Command line tool to interact with Redpesk
Url:            http://git.ovh.iot/redpesk/redpesk-infra/redpesk-cli.git
Source0:        %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       bash-completion

Recommends:     git
Recommends:     git-lfs

BuildRequires:  xz
BuildRequires:  git
BuildRequires:  golang >= 1.21

%description
rp-cli lets the user interact with the Redpesk platform just as the Redpesk web user interface (UI) does.
But when the web UI is a fancy graphical environment, rp-cli is made to be an easy and efficient tool, 
based on command line.
This is why rp-cli is great to automate every single action that can be done on the web UI. 
Nevertheless it is also much more. Indeed, for all the command line heroes out there, rp-cli has been designed 
to be easily manipulated and to be as intuitive as possible thank to its auto-completion.
Currently rp-cli is available for Linux environments only.

%prep
%setup -q -n %{repo}-%{version}
%setup -q -T -D -a 1
find . -iname "vendor" -type d

%build
VERSION=$(echo %{version} | cut -d. -f1,2,3)
export VERSION
SUB_VERSION=$(echo %{version} | cut -d. -f4)
export SUB_VERSION
make release

%install
install -D -m 0755 ./bin/%{_binary} %{buildroot}/%{_bindir}/%{_binary}
ln -s %{_binary} %{buildroot}/%{_bindir}/%{_binary_alias}
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
./bin/%{_binary} completion bash > %{buildroot}%{_sysconfdir}/bash_completion.d/%{_prompt}
sed -i "/complete -o default -F __start_rp-cli %{_binary}/a \ \ \ \ complete -o default -F __start_rp-cli %{_binary_alias}" %{buildroot}%{_sysconfdir}/bash_completion.d/%{_prompt}
sed -i "/complete -o default -o nospace -F __start_rp-cli %{_binary}/a \ \ \ \ complete -o default -o nospace -F __start_rp-cli %{_binary_alias}" %{buildroot}%{_sysconfdir}/bash_completion.d/%{_prompt}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_{completions,conf}.d
./bin/%{_binary} completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{_binary}
echo 'abbr --add %{_binary_alias} "%{_binary}"' > %{buildroot}%{_datadir}/fish/vendor_conf.d/rpcli.fish

%files
%defattr(-,root,root)
%{_bindir}/%{_binary}
%{_bindir}/%{_binary_alias}
%attr(644,root,root) %{_sysconfdir}/bash_completion.d/%{_prompt}
%attr(644,root,root) %{_datadir}/fish/vendor_completions.d/%{_binary}
%attr(644,root,root) %{_datadir}/fish/vendor_conf.d/rpcli.fish

%dir
%{_datadir}/fish
%{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_conf.d

%changelog
* Mon Nov 04 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.18.3
- Add offline possibility for several 'local' commands
- Enhance files upload to redpesk factory
- Add 'local package diff' command
- Code cleaning
- CI improvements
- Various minor bug fixes and enhancements

* Fri Oct 18 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.18.2
- 'local commit' command: filter files monitored in 'gitpkgs/' directory
- 'local commit' command: add support of '.gitignore'
- Add 'add' and 'update' commands for 'distributions' (admin users)
- Add the possibility to set-up the root directory inside the local-builder
- Take into account the CWD for 'local package' commands
- Various minor bug fixes and enhancements

* Thu Oct 03 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.18.1
- Use new version of 'local' command as default
- Documentation updates
- Various minor bug fixes and enhancements

* Wed Sep 18 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.18.0
- Adjustment to new automatic SRPMRebuild possibilities
- Adjustment to new way of downloading/uploading files (aka multipart)
- Enhance 'clean' sub-command of 'local-v2' command: now clean also mock
- Add possibility to use name instead of slug when looking for objects
- Add sub-version option in project update
- CI improvements
- Various minor bug fixes and enhancements

* Mon Aug 12 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.17.1
- Add sub-version support for projects and distributions

* Tue Jul 16 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.17.0
- Implementing new local subcommands group ('rp-cli local-v2')
- Add images build support in 'rp-cli projects build' command
- Requests optimizations when looking for projects, apps, images, board models, boards and teams
- Add 'noheader' global option (useful for scripts)
- Documentation updates
- Code cleaning
- Various minor bug fixes and enhancements

* Tue Apr 30 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.16.2
- Various minor bug fixes and enhancements

* Tue Apr 23 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.16.1
- Add comment on image build
- Add app's UUID possibility for 'projects builds'

* Fri Apr 12 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.16.0
- Add 'ditributions' sub-commands
- Add 'build' command for 'projects' 
- Documentation fixes
- Various minor bug fixes and enhancements

* Wed Jan 10 2024 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.15.0
- Change outputs for app/image builds
- Add fish completions
- Enhance paging interaction with user (use of 'next page' and 'prev page' keys)
- Documentation update
- Various minor bug fixes and enhancements

* Tue Oct 10 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.14.4
- onboard bug fix on fresh installation
- Various minor bug fixes

* Wed Sep 27 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.14.3
- Add 'local package clean' command
- Code cleaning
- CI improvements
- Various minor bug fixes and improvements

* Tue Sep 19 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.14.2
- Fix on app distributions update

* Tue Sep 19 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.14.1
- Add zip option when downloading logs
- Various minor bug fixes and improvements

* Thu Sep 14 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.14.0
- Bump to Golang 1.21
- Paging optimization when displaying objects list
- Various minor bug fixes and improvements

* Wed Jul 12 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.13.1
- Add 'cancel' subcommands for images and apps build
- Add 'local connections' subcommands
- Code cleaning
- CI improvements
- Various minor bug fixes and improvements

* Wed Jun 28 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.12.0
- Add support for 'build type' field in 'applications' and 'projects' commands
- Add 'images test' and 'images tests' commands
- Change 'local package run' to 'local package build' (compatibility kept)
- Code cleaning
- CI improvements
- Documentation fixes
- Various minor bug fixes and improvements

* Mon Apr 03 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.11.0
- Add connections subcommands
- Bump to Golang 1.17
- Implementations of 'apps builds stats' and 'apps tests stats'
- Add possibility to have custon localbuilder connection per factory connection
- Add fault code/msg in output of 'apps build get'
- Add Srpm build and check deps support for builds
- Add 'apps copy' command
- Code cleaning
- CI improvements
- Various minor bug fixes and improvements

* Tue Jan 10 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.10.1
- Postpone async build to 1.2.0

* Mon Jan 09 2023 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.10.0
- Add possibility to update sources of application
- Add branches management for applications ('rp-cli applications branch/branches')
- Allow container type for projects creation/update (flag '--containers')
- Convert shorthand to capital letters for global flags
- Add comment fields handling for builds and tests
- Code cleaning
- CI improvements
- Various minor bug fixes

* Fri Oct 28 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.9.3
- Better management of HTTP errors code
- Allow use of proxy server
- CI improvements
- Various minor bug fixes

* Wed Oct 12 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.9.2
- Add the 'projects releases deploy' command
- Add the 'deployments' subcommand group
- CI improvements
- Various minor bug fixes

* Tue Jul 26 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.9.1
- Update dependency to version 1.17 of Golang

* Wed Jul 20 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.9.0
- Add the 'boards' and 'board-models' subcommand groups
- Modification of the live 'tests' output, it enhances a lot the readability
- Add the possibility to select a board on which the tests are started
- Code cleaning
- CI improvements
- Various minor bug fixes

* Tue Jun 14 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.8.0
- Allow user to specify one distribution for build
- Enhance the outputs of builds: log, rpm, srpm and others are now available
- Add the possibility to ignore error with a global flag/option
- CI improvements
- Various minor bug fixes

* Fri May 13 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.7.0
- Update the repository output in 'projects get' command
- Enhance the 'images add' command for user convenience
- CI improvements
- Various minor bug fixes

* Wed Apr 27 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.6.0
- Add management of remote image build ('images build' and 'images builds')
- Add management of projects import/export ('projects import' and 'projects export')
- Add management of released projects ('projects release' and 'projects releases')
- Add management of released images ('images release' and 'images releases')
- Add management of applications audits ('applications audit' and 'applications audits')
- Add access tokens display for: projects, images, released projects and released images
- Add possibility to search in the commands tree with 'rp-cli misc cmd-search'
- Update documentation
- Various minor bug fixes

* Wed Mar 16 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.5.1
- Fix: cookie management when downloading build logs

* Wed Feb 23 2022 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.5.0
- Image management: add architecture check on additional repositories
- Fixes in documentation
- Adapation to new backend "GetAll"
- Add new subcommands:
- 'applications content' -> to get the list of files linked to an application
- 'applications download' -> to download an application file (specfile, tar.gz, etc.)
- 'applications remove' -> remove a file from an application
- Fix OS signals management
- Add "--model-board" flag in 'image add/update'
- Optimization on user input when app identified with its UUID
- Treat HTTP redirection as error

* Mon Dec 13 2021 Armand Bénéteau <armand.beneteau@iot.bzh> - 3.4.0
- Update specfile fields for applications
- Set "sources URL" field optional for applications add/update
- Adaptation to backend modifications
- CI improvements
- Enhance "services" management for applications