# Configuration

`rp-cli` configuration is easy thanks to the `rp-cli onboard` command. The user can configure interactively the two things that `rp-cli` may need:

* Connection to the redpesk infrastructure (to create, read, build and test applications and projects on the redpesk infrastructure)
* Connection to the local builder (to build and package locally an application that exists in the redpesk infrastructure)

## redpesk infrastructure access

In order to correctly communicate with the redpesk infrastructure, `rp-cli` needs to have the right parameters set.
To set these parameters easily and interactively, use the `rp-cli onboard` command, and answer yes (`Y`) to the first question it asks.

```bash
$ rp-cli onboard
Do you want to configure the redpesk backend connection? (Y/n)
> Y

-- Backend link configuration requested by user --

Current available connections: [NONE]

Please enter the alias of the connection you want to change/create, then press enter:
If you want to change/create the default connection, press enter directly
> 
Please enter the URL of the redpesk backend you want to interact with, then press enter:
> https://community-app.redpesk.bzh

Please visit https://community-app.redpesk.bzh with your favorite browser to create your access token!
The token section is available in your profile page. Please, paste your token here and press enter:
> 469427d5-63bc-4795-b4a2-30a89fded77f_a81f5295-ef5b-429d-b7c5-99cb0863d797
Deleting the previous configuration files...    [OK]
Creation of the configuration file...           [OK]
Modification of the token file...               [OK]
```

`rp-cli` first asks for an alias for the connection. Unless there are several redpesk servers you want to connect to, simply press enter. Then, it asks for the redpesk URL. In our example, we use the URL of the community redpesk infrastructure, i.e. [https://community-app.redpesk.bzh](https://community-app.redpesk.bzh). Then it requests an access token. This access token needs to be created through the webUI, following the steps here below.

* Go on the redpesk webUI, in your "Profile"

![Go to profile](images/redpesk_profile.png){:: style="margin:auto; display:flex; width: 70%;"}

* A new access token can be generated at the bottom of the page

![Generate token](images/redpesk_generate.png){:: style="margin:auto; display:flex; width: 70%;"}

* Set the client ID as "rp-cli" and choose an expiration date that suits you

![Fill the fields](images/redpesk_fill.png){:: style="margin:auto; display:flex; width: 70%;"}

* Once the access token generated, copy it in your clipboard. Be careful, your access token is just displayed once!

![Copy the access token](images/redpesk_accesstoken.png){:: style="margin:auto; display:flex; width: 70%;"}

## Local builder connection

### Local builder URL

Before configuring `rp-cli` to interact with the local builder, it is strongly advised to follow the installation guide of the local builder available [here]({% chapter_link local-builder-doc.installation %}).
In the following guide, we consider that you choose the default path for the mounted directories in the local builder.

Once the connection to the redpesk infrastructure is completed, or if you have answered no (`n`) to the first question, the `rp-cli onboard` then asks if you want to configure the redpesk localbuilder connection. If you want to, answer yes (`Y`).

```bash
$ rp-cli onboard
Do you want to configure the redpesk backend connection? (Y/n)
> n


Do you want to configure the redpesk local-builder connection? (Y/n)
> Y

-- Local builder link configuration requested by user --

Current available connections: [NONE]

Please enter the IP of the local builder you want to interact with (ex: 10.231.232.2), then press enter:
> 10.231.232.187
Modification of the local builder file...       [OK]

The default mounted directory (/home/devel/my_rp_builder_dir/gitsources) exists on the host, should it be used as 'gitsources' directory? (Y/n)

> y

The default mounted directory (/home/devel/my_rp_builder_dir/gitpkgs) exists on the host, should it be used as 'gitpkgs' directory? (Y/n)

> y
```

`rp-cli` first requests the IP of the local builder. Enter the IP of the corresponding container running on your host and press enter. To get this IP, two methods are available, depending if you are using `incus` or `docker`.

* With **`incus`**

```bash
> incus ls redpesk-localbuilder
+----------------------+---------+---------------------+------+-----------+-----------+
|         NAME         |  STATE  |        IPV4         | IPV6 |   TYPE    | SNAPSHOTS |
+----------------------+---------+---------------------+------+-----------+-----------+
| redpesk-localbuilder | RUNNING | 10.171.7.234 (eth0) |      | CONTAINER | 0         |
+----------------------+---------+---------------------+------+-----------+-----------+
```

* With **`docker`**

```bash
> docker inspect -f json redpesk-localbuilder |jq .[].NetworkSettings.IPAddress
"172.17.0.3"
```

Then, it checks that the `~/my_rp_builder_dir/gitsources` and `~/my_rp_builder_dir/gitpkgs` directories exist. If they exist, it asks the user if he wants to use them as `gitsources` and `gitpkgs` mounted directories.
If, at local builder installation time, you chose the default mounted directories, it is all good for you! In the other case, answer `n` to the question and enter the right path.

## Shell Completion

The `rp-cli` user experience takes advantage of the shell completion. All the installation and configuration steps needed by completion are automatically handled when installing the `redpesk-cli` package.

### Autocompletion usage

Using `rp-cli`'s autocompletion is really simple, and as you may already know, autocompletion can really be a timesaver!
In order to use it, simply start typing the command line you want, and then hit `[TAB][TAB]`. Depending on what you are currently typing, the completion suggests you the end of your command.

It even looks for the projects/applications list from the backend to suggest them to you. You can find some examples here below.

```bash
# Get the list of sub-commands with autocompletion
$ rp-cli [TAB][TAB]
admin         (Commands group for the redpesk factory administration)       misc          (Miscellaneous commands group)
applications  (Applications commands group)                               onboard       (Set up the whole rp-cli configuration interactively)
help          (Help about any command)                                    projects      (Projects commands group)
images        (Images commands group)                                     teams         (Teams commands group)
iotpkg        (Iotpkg wrapper (iotpkg running within the local-builder))  users         (Users commands group)
local         (Local commands group)

# Get the list of mandatory flags in "applications add" sub-command
$ rp-cli applications add -[TAB][TAB]
--name      ([Mandatory] Name of the application to create)
--pkg-name  ([Mandatory] RPM package name that must match the "name" value of the specfile)
-n          ([Mandatory] Name of the application to create)

# Get the list of available applications to build
$ rp-cli applications build [TAB][TAB]
helloworld-binding      python3-pytest-tap      python3-tap-py          redtest-helloworld-api

# Etc.
```

## Administrator use

An `admin` sub-commands group is hidden by default in the `rp-cli` tool. In order to see these commands in the helpers and to have the completion features enabled on the `admin` sub-commands, you need to prove `rp-cli` that you are an administrator of the redpesk factory.

In order to do that, you need first to correctly configure `rp-cli` to communicate with the redpesk factory you are using (cf. paragraphs here above).

Then, simply run the following command.

```bash
$ rp-cli admin init
-- Check and initialize admin rights --
Result: [OK]
```

From now, you have access to the full `admin` sub-command and the completion on it.
