# Commands list

`rp-cli` can do much more than what is in the examples list. Here below, the exhaustive list of all the `rp-cli` commands and sub-commands.

Nevertheless, `rp-cli`'s inline help is really furnished. Thus, use the `--help` or `-h` flags with any command, or sub-command, as soon as you need information!

Here is the tree of supported commands and subcommands (you can get it live using `rpcli misc cmd-tree` or search one command using `rpcli misc cmd-search`) :

```
rp-cli                       -- Command line tool for Redpesk platform
├── admin                    -- Commands group for the redpesk factory administration
│   ├── import-image         -- Import an image object in the backend
│   ├── import-project       -- Import a project, existing in Koji, in the backend
│   └── init                 -- Check that the user has administrator privileges and save it in configuration file
├── applications             -- Applications commands group
│   ├── add                  -- Create a new application
│   ├── add-from-sample      -- Create a new application from a sample application retrieved from redpesk factory
│   ├── audit                -- Start auditing an application
│   ├── audits               -- Subcommands group relative to "audits" of an application
│   │   ├── get              -- Get the properties and results of an audit
│   │   ├── list             -- List all the audits of an application
│   │   ├── logs             -- Download the application audit logs
│   │   └── tools            -- List all the tools available to audit an application
│   ├── bookmark             -- Bookmark an application
│   ├── branch               -- Create a new branch or switch to an existing one within an application
│   ├── branches             -- Subcommands group relative to "branches" of an application
│   │   ├── delete           -- Delete the branch <branch-ID> from the application <app-ID>
│   │   └── list             -- List all the branches of an application
│   ├── build                -- Start building an application on the redpesk factory
│   ├── builds               -- Group of subcommands relative to "builds" of an application
│   │   ├── cancel           -- Cancel a running build
│   │   ├── get              -- Get the properties of a build
│   │   ├── list             -- List all the builds of an application
│   │   ├── logs             -- Download the application build logs
│   │   └── stats            -- Display build statistics of the given application
│   ├── copy                 -- Copy the application to another project.
│   ├── delete               -- Delete an application
│   ├── files                -- Subcommands group relative to application files
│   │   ├── download         -- Download file(s) of an application
│   │   ├── list             -- List the files of an application
│   │   ├── remove           -- Remove file(s) of an application
│   │   └── upload           -- Upload one or several files for an application
│   ├── get                  -- Get the properties of an application
│   ├── list                 -- List the applications from a project or from the whole redpesk infrastructure
│   ├── refresh-files-pkg    -- Refresh gitpkg generated files (including tarballs) for the application
│   ├── services             -- List the available services for an application built with redpesk
│   ├── test                 -- Start a test run for an application
│   ├── tests                -- Group of subcommands relative to "tests" of an application
│   │   ├── cancel           -- Cancel a test currently running
│   │   ├── get              -- Get the properties of a test
│   │   ├── list             -- List all the test runs done on an application
│   │   ├── logs             -- Download the application test logs
│   │   └── stats            -- Display test statistics of the given application
│   └── update               -- Update an application settings
├── board-models             -- Board models commands group
│   ├── get                  -- Get the properties of a board model
│   └── list                 -- List the supported board models in Redpesk infrastructure
├── boards                   -- Boards commands group
│   ├── get                  -- Get the properties of a board
│   └── list                 -- List the supported boards in Redpesk infrastructure
├── connections              -- Connections commands group
│   ├── add                  -- Define a new connection
│   ├── current              -- Display the current connection used by rp-cli
│   ├── delete               -- Delete one connection from the factory connections list
│   ├── get                  -- Get the properties of a connection from its alias
│   ├── list                 -- List the available connections to different redpesk factories
│   ├── update               -- Update an existing connection
│   └── use                  -- Change the redpesk factory connection currently used by rp-cli
├── deployments              -- Deployments commands group
│   ├── get                  -- Get the properties of a deployment
│   └── list                 -- List the deployments performed in the redpesk factory
├── distributions            -- Distributions commands group
│   ├── add                  -- Add/Import a distribution, existing in Koji, in the factory
│   ├── get                  -- Get the properties of a distribution
│   ├── list                 -- List the available distributions on redpesk factory
│   ├── packages             -- List the packages contained in a distribution
│   └── update               -- Update a distribution in the factory
├── help                     -- Help about any command
├── images                   -- Images commands group
│   ├── add                  -- Create a new image
│   ├── build                -- Start building an image on the redpesk factory
│   ├── builds               -- Group of subcommands relative to "builds" of an image
│   │   ├── cancel           -- Cancel a running build
│   │   ├── get              -- Get the properties of a build
│   │   ├── list             -- List all the builds of an image
│   │   └── logs             -- Download the image build logs
│   ├── delete               -- Delete an image
│   ├── get                  -- Get the properties of an image
│   ├── list                 -- List the images from the redpesk infrastructure
│   ├── localbuild           -- Start building a redpesk image locally
│   ├── release              -- Release a redpesk image in the redpesk factory
│   ├── releases             -- Images releases sub-commands group
│   │   ├── delete           -- Delete a released image
│   │   ├── get              -- Get the properties of a released image
│   │   ├── list             -- List the released images from the infrastructure
│   │   └── update           -- Update a released image settings (info and audience)
│   ├── test                 -- Start a test run for an image
│   ├── tests                -- Group of subcommands relative to "tests" of an image
│   │   ├── cancel           -- Cancel a test currently running
│   │   ├── get              -- Get the properties of a test
│   │   ├── list             -- List all the test runs done on an image
│   │   ├── logs             -- Download the image test logs
│   │   └── stats            -- Display test statistics of the given image
│   └── update               -- Update an image settings
├── iotpkg                   -- Iotpkg wrapper (iotpkg running within the local-builder)
├── local                    -- Local commands group
│   ├── check-setup          -- Check that the host is correctly set-up to use the local-builder
│   ├── connections          -- Subcommands group relative to the localbuilder connections
│   │   ├── add              -- Define a new connection
│   │   ├── current          -- Display the current connection used by rp-cli
│   │   ├── delete           -- Delete one connection from the local-builder connections list
│   │   ├── get              -- Get the properties of a connection from its alias
│   │   ├── list             -- List the available connections to different local-builders
│   │   ├── update           -- Update an existing connection
│   │   └── use              -- Change the local-builder connection currently used by rp-cli
│   ├── exec                 -- Execute a command line in the local-builder
│   └── package              -- Packaging sub-command group
│       ├── build            -- Build locally an application
│       ├── clean            -- Delete all the directories created for local building
│       ├── commit           -- Upload files that have been modified/added/deleted in your working directory, to the remote gitpkg in the redpesk factory
│       ├── diff             -- Files comparison between the local version and the factory version
│       ├── fetch            -- Fetch content from the redpesk factory, create or update a local working directory
│       ├── init             -- Initialization needed by the local builder to package
│       ├── metadata         -- Set application metadata value
│       ├── service          -- Set application service value
│       ├── shell            -- Allow to get a shell inside the mock used to build
│       └── status           -- Show the status of files in the 'gitpkgs/' directory used to local build the application
├── misc                     -- Miscellaneous commands group
│   ├── arch                 -- List the supported architectures for Redpesk
│   ├── cmd-search           -- Allows to run a research on the available commands of 'rp-cli'
│   ├── cmd-tree             -- Display the full list of commands and sub-command available for rp-cli (usefull for doc.)
│   ├── configuration        -- Display rp-cli's current configuration parameters
│   │   ├── get              -- Get the value of a persistent parameter, in the configuration file
│   │   └── set              -- Set the value of a persistent parameter, in the configuration file
│   ├── status               -- Get the Redpesk infrastructure configuration status
│   └── version              -- Get the Redpesk back-end's version
├── onboard                  -- Set up the whole rp-cli configuration interactively
├── projects                 -- Projects commands group
│   ├── add                  -- Create a new project
│   ├── bookmark             -- Bookmark a project
│   ├── build                -- Group of subcommands to build a project objects (apps, images or all)
│   │   ├── all              -- Start building all the project's objects on the redpesk factory
│   │   ├── applications     -- Start building the project's apps on the redpesk factory
│   │   └── images           -- Start building the project's images on the redpesk factory
│   ├── builds               -- Group of subcommands relative to "builds" of a project
│   │   ├── matrix           -- Display a matrix of builds per application and per distribution
│   │   └── stats            -- Display build statistics of the given project
│   ├── delete               -- Delete a project
│   ├── export               -- Projects export sub-commands group
│   │   ├── download         -- Download manually the export archive to the specified directory
│   │   ├── get              -- Display the current export status
│   │   └── start            -- Start the export of the specified project
│   ├── get                  -- Get the properties of a project
│   ├── import               -- Projects import sub-commands group
│   │   ├── get              -- Display the current import status
│   │   └── start            -- Upload the project archive and start to import it
│   ├── list                 -- List the projects from the Redpesk infrastructure
│   ├── members              -- Projects members sub-commands group
│   │   ├── add              -- Add a user as member of a project
│   │   ├── delete           -- Delete a member of a project
│   │   ├── get              -- List the members of a project
│   │   └── update           -- Update a project member's roles
│   ├── release              -- Release a project on the factory
│   ├── releases             -- Projects releases sub-commands group
│   │   ├── delete           -- Delete a released project
│   │   ├── deploy           -- Deploy a released project on one or several boards
│   │   ├── get              -- Get the properties of a released project
│   │   ├── list             -- List the released projects from the infrastructure
│   │   └── update           -- Update a released project settings (info and audience)
│   ├── tests                -- Group of subcommands relative to "tests" of a project
│   │   └── stats            -- Display test statistics of the given project
│   └── update               -- Update a project settings
├── teams                    -- Teams commands group
│   ├── add                  -- Create a new team
│   ├── del-member           -- Delete a member from a team
│   ├── get                  -- Get the properties of a team
│   ├── invite               -- Invite a user or a team in another team
│   ├── list                 -- List the teams from the Redpesk infrastructure
│   └── update               -- Update a team settings
└── users                    -- Users commands group
    ├── add                  -- Create a new user
    ├── disable              -- Disable a user
    ├── enable               -- Enable a user
    ├── get                  -- Get the properties of a user
    ├── list                 -- List the users from the Redpesk infrastructure
    └── update               -- Update a user settings
```
