# Global configuration

Few parameters are "global" in `rp-cli` environment. Here, "global" means that these parameters are present for all the `rp-cli` sub-commands, and they can have an effect on all these sub-commands.

These parameters appear systematically in the 'Global Flags' section, in the "help" documentation returned by `rp-cli` when the `--help` flag is specified.

```bash
Global Flags:
  -c, --config string        Config file containing the user options (default are $HOME/.redpesk/rp-cli/rp-cli-config.json or /etc/redpesk/rp-cli/rp-cli-config.json)
      --logfilename string   Filename where logs will be redirected (default "stderr")
  -l, --loglevel string      Logging level (supported levels: panic, fatal, error, warn, info, debug) (default "warn")
      --nonblocking          When set, rp-cli never waits for events on the websocket (builds, tests, etc.)
      --rawoutput            When set, rp-cli output only machine readable text (json) that corresponds to the Redpesk backend answers
      --serveralias string   Alias for the connection parameters to use to connect on the Redpesk server (default "default")
  -t, --timestamp            Prefix output with timestamp [NOT IMPLEMENTED YET]
```

For all of these parameters, it exists 3 different ways to modify their values:

* By modifying their values in the configuration file (by default under `$HOME/.redpesk/rp-cli/rp-cli-config.json`)
* By setting the corresponding environment variable to the value wanted (ex: `export RP_LOGLEVEL=debug`)
* By passing the corresponding flag to the value wanted directly in the command line.

The priority order for the ways are:

1. Flag in the command line
2. Value of the environment variable
3. Value in the configuration file

Finally, the different form for each parameters are:

* `"parameter"`  -> in the configuration file
* `RP_PARAMETER` -> for the environment variable form
* `--parameter`  -> for the flag form

For example:

* `"loglevel"`
* `RP_LOGLEVEL`
* `--loglevel`

**N.B.**: In order to have the list of all environment variables corresponding to global parameters, simply run `rp-cli misc configuration`

## Get/set configuration file parameters

Two `rp-cli` subcommands allow to easily handle the different parameters that can be modified in the configuration file.
These subcommands are:

* `rp-cli misc configuration get <config-param>` -> get the value of a parameter set in the configuration file
* `rp-cli misc configuration set <config-param> --value <new_value>` -> set the value of a parameter in the configuration file

Thanks to that, the behavior of `rp-cli` can be modified without having to modify manually the configuration file.
Moreover, the completion is available on the `<config-param>`, allowing the user to see all the parameters available.

The most helpful use cases are:

* Setting the `gitpkgs/` directory for `rp-cli local` commands: `rp-cli misc configuration set pkgsdir --value "~/my_rp_builder_dir/gitpkgs"`
* Setting the `gitsources/` directory for `rp-cli local` commands: `rp-cli misc configuration set sourcesdir --value "~/my_rp_builder_dir/gitsources"`
