# Redpesk command line interface: rp-cli

`rp-cli` lets the user interact with the Redpesk platform just as the Redpesk web user interface (UI) does. But when the web UI is a fancy graphical environment, `rp-cli` is made to be an easy and efficient tool, based on command line.

This is why `rp-cli` is great to automate every single action that can be done on the web UI. Nevertheless it is also much more. Indeed, for all the command line heroes out there, `rp-cli` has been designed to be easily manipulated and to be as intuitive as possible thank to its auto-completion.

Currently `rp-cli` is available for Linux environments only.

## Installation

The `rp-cli` binary is available as rpm or debian package on the Redpesk "devtools" repository. Therefore it can be easily installed following the instructions here below.
Please use the right paragraph, according to you distribution.

### Ubuntu 20.04 and 18.04

Firstly, add the Redpesk "devtools" repository in the list of your packages repositories.

```bash
# Add the repository in your list
$ echo "deb https://download.redpesk.bzh/redpesk-devel/releases/33/sdk/xUbuntu_20.04/ ./" | sudo tee -a /etc/apt/sources.list
# Add the repository key
$ curl -L https://download.redpesk.bzh/redpesk-devel/releases/33/sdk/xUbuntu_20.04/Release.key | sudo apt-key add -
```

Then, update the list of packages and simply install the `redpesk-cli` package.

```bash
# Update the list of available packages
$ sudo apt update
# Installation of redpesk-cli
$ sudo apt-get install redpesk-cli
```

In order for the autocompletion to work, it is necessary to reload your terminal.

### Fedora 32 and 33

Firstly, add the Redpesk "devtools" repository in the list of your packages repositories.
Set the `FEDORA_VERSION` variable according to your version. In the example, the version `32` is used.
Available versions are `32` and `33`.

```bash
$ FEDORA_VERSION=32 # Set the right Fedora version
$ cat << EOF > /etc/yum.repos.d/redpesk-devtools.repo
[redpesk-devtools]
name=redpesk-devtools
baseurl=https://download.redpesk.bzh/redpesk-devel/releases/33/sdk/Fedora_$FEDORA_VERSION
enabled=1
repo_gpgcheck=0
type=rpm
gpgcheck=0
skip_if_unavailable=True
EOF
```

Then, simply install the `redpesk-cli` package.

```bash
dnf install redpesk-cli
```

In order for the autocompletion to work, it is necessary to reload your terminal.

### OpenSUSE Leap 15.2

Firstly, add the Redpesk "devtools" repository in the list of your packages repositories.

```bash
# Add the repository in your list
$ sudo zypper ar https://download.redpesk.bzh/redpesk-devel/releases/33/sdk/openSUSE_Leap_15.2/ redpesk-devtools
# Refresh your repositories
$ sudo zypper ref
```

Then, simply install the `redpesk-cli` package.

```bash
sudo zypper in redpesk-cli
```

In order for the autocompletion to work, it is necessary to reload your terminal.

## Configuration

### Redpesk infrastructure access

In order to correctly communicate with the Redpesk infrastructure, `rp-cli` needs to have the right parameters set.
To set these parameters easily and interactively, use the `rp-cli onboard` command.

```bash
$ rp-cli onboard
-- rp-cli configuration requested by user --
Current available connections: [NONE]

Please enter the alias of the connection you want to change/create, then press enter:
If you want to change/create the default connection, press enter directly
> 

Please enter the URL of the redpesk backend you want to interact with, then press enter:
> https://community-app.redpesk.bzh

Please visit https://community-app.redpesk.bzh with your favorite browser to create your access token!
The token section is available in your profile page. Please, paste your token here and press enter:
> 7b1f5f04-bbb8-42b4-96bc-bde36beee1e3_a28fef78-320b-4d43-a676-ce68d48d2c71
Deleting the previous configuration files...    [OK]
Creation of the configuration file...           [OK]
Modification of the token file...               [OK]
```
`rp-cli` first asks for an alias for the connection. Unless there are several redpesk servers you want to connect to, simply press enter. Then, this command asks for the redpesk URL. In our example, we use the URL of the community redpesk infrastructure, i.e. [https://community-app.redpesk.bzh](https://community-app.redpesk.bzh). Then it requests an access token. This access token needs to be created through the webUI, following the steps here below.

* Go on the Redpesk webUI, in your "Profile"

![Go to profile](images/redpesk_profile.png){:: style="margin:auto; display:flex; width: 70%;"}

* A new access token can be generated at the bottom of the page

![Generate token](images/redpesk_generate.png){:: style="margin:auto; display:flex; width: 70%;"}

* Set the client ID as "rp-cli" and choose an expiration date that suits you

![Fill the fields](images/redpesk_fill.png){:: style="margin:auto; display:flex; width: 70%;"}

* Once the access token generated, copy it in your clipboard. Be careful, your access token is just displayed once!

![Copy the access token](images/redpesk_accesstoken.png){:: style="margin:auto; display:flex; width: 70%;"}

### Shell Completion

The `rp-cli` user experience takes advantage of the shell completion. All the installation and configuration steps needed by completion are automatically handled when installing the `redpesk-cli` package.

#### Autocompletion usage

Using `rp-cli`'s autocompletion is really simple, and as you may already know, autocompletion can really be a timesaver!
In order to use it, simply start typing the command line you want, and then hit `[TAB][TAB]`. Depending on what you are currently typing, the completion suggests you the end of your command.

It even looks for the projects/applications list from the backend to suggest them to you. You can find some examples here below.

```bash
# Get the list of sub-commands with autocompletion
$ rp-cli [TAB][TAB]
applications    help    misc    onboard    projects    teams    users

# Get the list of mandatory flags in "applications add" sub-command
$ rp-cli applications add -[TAB][TAB]
-n             --name=        --pkg-name=    --source-url=

# Get the list of available applications to build
$ rp-cli applications build [TAB][TAB]
borderland-3-my-app-0  iot-project-iot-app-0

# Etc.
```

## Commands examples

Here below, few basic examples of rp-cli use.

```bash
# Get the list of all the available architectures in the Redpesk instance
rp-cli misc arch

# Get the list of all the available distributions in the Redpesk instance
rp-cli misc distributions

# Get the list of all the available projects in the Redpesk instance (verbose option)
rp-cli projects list -v

# Get the list of all the available applications in the Redpesk instance (no verbose option)
rp-cli applications list

# Creation of a new project called "IOT Project", without waiting for the acknowledgement events
rp-cli projects add --nonblocking -n "IOT Project" --mandatory-arch x86_64 --optional-arch aarch64 --mandatory-distro redpesk-devel-arz

# Creation of a new app "IOT Application" in the project with the slug "iot-project"
rp-cli applications add --name "IOT Application" -d "This is my beautiful app" --pkg-name "agl-service-helloworld" --source-rev "master-next" --source-url "http://git.ovh.iot/redpesk/redpesk-samples/agl-service-helloworld.git" -p "iot-project"

# Upload a specfile for the application with the slug "iot-application"
rp-cli applications upload iot-application --file-path /home/me/iot-app.spec

# Get the list of all the available applications in the project with the slug "iot-project" in the Redpesk instance
rp-cli applications list -p iot-project

# Start a new build for the application "iot-application", verbose option
rp-cli applications build iot-application -v

# Start a new test for the application "iot-application", on the latest build, verbose option
rp-cli applications test iot-application -v

# Start a new test for the application "iot-application", on the build #1068
rp-cli applications test iot-application --build 1068

# Get the list of all the builds for the application "iot-application", with verbose option
rp-cli applications builds-list iot-application -v

# Get the list of all the tests for the application "iot-application"
rp-cli applications tests-list iot-application

# Get the list of public teams in the Redpesk instance, with verbose option
rp-cli teams list --verbose
```

## Commands list

`rp-cli` can do much more than what is in the examples list. Here below, the exhaustive list of all the `rp-cli` commands and sub-commands.

Nevertheless, `rp-cli`'s inline help is really furnished. Thus, use the `--help` or `-h` flags with any command, or sub-command, as soon as you need information!

```text
rp-cli
│
├── applications -- Applications commands group
|   │
│   ├── add         -- Create a new application
│   ├── build       -- Start building an application
│   ├── builds-list -- List all the builds of an application
│   ├── delete      -- Delete an application
│   ├── get         -- Get the properties of an application
│   ├── list        -- List the applications from a project or from the whole Redpesk infrastructure
│   ├── test        -- Start a test run for an application
│   ├── tests-list  -- List all the test runs done on an application
│   ├── update      -- Update an application settings
│   └── upload      -- Upload a file for an application
│
│
├── help -- Help provides help for any command in the application
│
│
├── misc -- Miscellaneous commands group
|   │
│   ├── add-connection  -- Define a new connection
│   ├── arch            -- List the supported architectures for Redpesk
│   ├── configuration   -- Display rp-cli's current configuration parameters
│   ├── distributions   -- List the available distributions for Redpesk
│   ├── status          -- Get the Redpesk infrastructure configuration status
│   └── version         -- Get the Redpesk back-end's version
│
│
├── onboard -- Set up the whole rp-cli configuration interactively
│
│
├── projects -- Projects commands group
|   │
│   ├── add     -- Create a new project
│   ├── delete  -- Delete a project
│   ├── get     -- Get the properties of a project
│   ├── list    -- List the projects from the Redpesk infrastructure
│   ├── members -- Projects members sub-commands group
│   │   ├── add    -- Add a user as member of a project
│   │   ├── delete -- Delete a member of a project
│   │   ├── get    -- List the members of a project
│   │   └── update -- Update a project member's roles
│   └── update  -- Update a project settings
│
│
├── teams -- Teams commands group
|   │
│   ├── add    -- Create a new team
│   ├── get    -- Get the properties of a team
│   ├── invite -- Invite a user or a team in another team
│   ├── list   -- List the teams from the Redpesk infrastructure
│   └── update -- Update a team settings
│
│
└── users -- Users commands group
    |
    ├── add     -- Create a new user
    ├── disable -- Disable a user
    ├── enable  -- Enable a user
    ├── get     -- Get the properties of a user
    ├── list    -- List the users from the Redpesk infrastructure
    └── update  -- Update a user settings
```
