/**
 * Copyright (C) 2022-2023 IoT.bzh Company
 * Contact: https://www.iot.bzh/licensing
 *
 * This file is part of the redpesk-cli project, the redpesk command line tool.
 *
 * $RP_BEGIN_LICENSE$
 * Commercial License Usage
 *  Licensees holding valid commercial IoT.bzh licenses may use this file in
 *  accordance with the commercial license agreement provided with the
 *  Software or, alternatively, in accordance with the terms contained in
 *  a written agreement between you and The IoT.bzh Company. For licensing terms
 *  and conditions see https://www.iot.bzh/terms-conditions. For further
 *  information use the contact form at https://www.iot.bzh/contact.
 *
 * GNU General Public License Usage
 *  Alternatively, this file may be used under the terms of the GNU General
 *  Public license version 3. This license is as published by the Free Software
 *  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 *  of this file. Please review the following information to ensure the GNU
 *  General Public License requirements will be met
 *  https://www.gnu.org/licenses/gpl-3.0.html.
 * $RP_END_LICENSE$
 */

package bckapi

import (
	"fmt"

	"git.ovh.iot/redpesk/redpesk-infra/rp-webserver/actions/rpapiv1"
)

// BuildGet gets a full build structure from its ID
//
// :param build: Pointer to the rpapiv1.RPBuildFull structure to fill
// :type build: *rpapiv1.RPBuildFull
// :param bldID: build ID
// :type bldID: string
// :returns: error -- an error if a problem has occurred
func (rpAPIInterface *RPBCKAPI) BuildGet(build *rpapiv1.RPBuildFull, buildID string) error {
	// Send the appropriate GET request
	if err := rpAPIInterface.HTTPCli.Get(fmt.Sprintf(buildIDRoute, buildID), build); err != nil {
		return errorInterpreter(err, "")
	}

	return nil
}

// BuildCancel allows the user to cancel a running build
//
// :param bldID: build ID
// :type bldID: string
// :param bldAns: Pointer to the rpapiv1.RPBuildFull structure to fill
// :type bldAns: *rpapiv1.RPBuildFull
// :returns: error -- an error if a problem has occurred
func (rpAPIInterface *RPBCKAPI) BuildCancel(buildID string, bldAns *rpapiv1.RPBuildFull) error {
	var tmpAns *rpapiv1.RPBuildFull

	if bldAns == nil {
		tmpAns = &rpapiv1.RPBuildFull{}
	} else {
		tmpAns = bldAns
	}

	// Send the appropriate Post request
	if err := rpAPIInterface.HTTPCli.Post(fmt.Sprintf(buildCancelRoute, buildID), nil, tmpAns); err != nil {
		return errorInterpreter(err, "")
	}

	return nil
}
