/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package bckapi

const (
	// Logs prefix
	bckLogPrefix = "[RPSERVER] "

	// URL prefix
	urlPrefix = "/api/v1"

	// Cookie key
	bckCookieKey = "rp-sid"

	// Authorization constants
	authorizationHeader = "Authorization"
	bearerPrefix        = "Bearer "

	// Paging constants
	objectFirstPage = "1"
	objectNbPerPage = "50"

	// Backend routes

	// Events routes
	eventsRoute        = "/events"
	evtRegisterRoute   = eventsRoute + "/register"
	evtUnregisterRoute = eventsRoute + "/unregister"

	// Misc command
	versionRoute  = "/version"
	configRoute   = "/config"
	archRoute     = "/architectures"
	rolesRoute    = "/roles"
	servicesRoute = "/applications/services"

	newAppMetadataDefVersion = "1.6.0"
	newAutoSRPMBuildVersion  = "1.7.0"
	multipartFileVersion     = "1.7.0"

	// Roles command
	myRolesRoute = "/roles/me"

	// Users command
	usersRoute         = "/users"
	usersIDRoute       = usersRoute + "/%s"
	usersMeRoute       = usersRoute + "/me"
	usersEnableDisable = usersRoute + "/%s/enable-disable"

	// Teams command
	teamsRoute                = "/teams"
	teamsIDRoute              = teamsRoute + "/%s"
	teamsMemberRoute          = teamsIDRoute + "/members"
	teamsMemberInvitRoute     = teamsMemberRoute + "/invitation"
	teamsNewMembersListRoute  = teamsMemberRoute + "/newmember"
	teamsExtMemberInviteRoute = teamsMemberRoute + "ext/invitation"

	// Project command
	projectRoute                = "/projects"
	projectRoutePrefix          = projectRoute + "/"
	projectUpdateRoute          = projectRoutePrefix + "%s"
	projectBuildConfigRoute     = projectRoutePrefix + "%s" + "/buildconfig"
	projectExportRoute          = projectRoutePrefix + "%s" + "/export"
	projectExportDownloadRoute  = projectExportRoute + "/download"
	projectImportUploadRoute    = projectRoutePrefix + "import"
	projectImportRoute          = projectRoutePrefix + "%s" + "/import"
	projectBookmarkRoute        = projectRoutePrefix + "%s" + "/bookmark"
	projectReleaseRoute         = projectRoutePrefix + "%s" + "/release"
	projectBuildsStatsRoute     = projectRoutePrefix + "%s" + "/builds/stats"
	projectBuildsRoute          = projectRoutePrefix + "%s" + "/builds"
	projectTestsStatsRoute      = projectRoutePrefix + "%s" + "/tests/stats"
	projectRepoInfoRoute        = projectRoutePrefix + "%s" + "/repo_info"
	projectRepoInheritanceRoute = projectRoutePrefix + "%s" + "/repos_inheritances"

	// Released project commands
	releasedProjectRoute           = "/release-projects"
	releasedProjectRoutePrefix     = releasedProjectRoute + "/"
	releasedProjectIDRoute         = releasedProjectRoutePrefix + "%s"
	releasedProjectAudienceRoute   = releasedProjectIDRoute + "/audience"
	releasedProjectDeployRoute     = releasedProjectIDRoute + "/deploy"
	releasedProjectDeploymentRoute = releasedProjectIDRoute + "/deployments"

	// Deployments command
	deploymentRoute       = "/deployments"
	deploymentRoutePrefix = deploymentRoute + "/"
	deploymentIDRoute     = deploymentRoutePrefix + "%s"

	projectMngtRoute        = "/projects-mngt"
	projectMngtRoutePrefix  = projectMngtRoute + "/"
	projectMngtImportRoute  = projectMngtRoutePrefix + "import"
	projectMngtRefreshRoute = projectMngtRoutePrefix + "%s" + "/refresh"

	// Members command
	prjMembersRoute      = projectRoutePrefix + "%s/members"
	prjNewMembersRoute   = projectRoutePrefix + "%s/members/newmember"
	prjMembersRolesRoute = projectRoutePrefix + "%s/roles"

	// Applications command
	allAppsRoute         = "/applications"
	appCreationRoute     = projectRoutePrefix + "%s/applications"
	appIDRoute           = allAppsRoute + "/%s"
	appDeletionRoute     = appIDRoute
	appBuildRoute        = appIDRoute + "/builds"
	appListFilesRoute    = appIDRoute + "/listfile"
	appRemoveFileRoute   = appIDRoute + "/file"
	appDownloadFileRoute = appIDRoute + "/file"
	appUploadFileRoute   = appIDRoute + "/file"
	appTestRoute         = "/builds/%s/tests"
	appUpdateRoute       = appIDRoute
	appBookmarkRoute     = appIDRoute + "/bookmark"
	appServiceRoute      = allAppsRoute + "/services"
	appSamplesRoute      = allAppsRoute + "/samples"
	appAuditRoute        = appIDRoute + "/audits"
	appBranchesRoute     = appIDRoute + "/branches"
	appActionRoute       = appIDRoute + "/action"

	// Builds command
	buildsRoute      = "/builds"
	buildIDRoute     = buildsRoute + "/%s"
	buildCancelRoute = buildIDRoute + "/cancel"

	// Audits command
	auditsRoute          = "/audits"
	auditsIDRoute        = auditsRoute + "/%s"
	auditsLogRoute       = auditsIDRoute + "/logs"
	auditsListToolsRoute = auditsRoute + "/list"

	// Tests command
	testsRoute             = "/tests"
	testGetRoute           = testsRoute + "/%s"
	testLogsFilesListRoute = testGetRoute + "/listfiles"
	testLogsFileRoute      = testGetRoute + "/logs?name=%s"
	testCancelRoute        = testGetRoute + "/cancel"
	testsGetFromBuildRoute = buildIDRoute + "/tests"

	// Images command
	imagesRoute             = "/images"
	imagesRoutePrefix       = imagesRoute + "/"
	imagesIDRoute           = imagesRoutePrefix + "%s"
	imagesBookmarkRoute     = imagesIDRoute + "/bookmark"
	imagesReleaseRoute      = imagesIDRoute + "/release"
	imagesTeamsReleaseRoute = imagesIDRoute + "/teamsrelease"
	imagesBuildRoute        = imagesIDRoute + "/builds"

	imagesMngtRoute       = "/images-mngt"
	imagesMngtRoutePrefix = imagesMngtRoute + "/"
	imagesMngtImportRoute = imagesMngtRoutePrefix + "import"

	// Released image commands
	releasedImageRoute         = "/release-images"
	releasedImageRoutePrefix   = releasedImageRoute + "/"
	releasedImageIDRoute       = releasedImageRoutePrefix + "%s"
	releasedImageAudienceRoute = releasedImageIDRoute + "/audience"

	// Board models command
	modelBoardsRoute = "/modelboards"

	// Boards command
	boardsRoute = "/boards"

	// All the object types
	appObjectType            = "application"
	projectObjectType        = "project"
	releaseProjectObjectType = "release-project"
	releaseImageObjectType   = "release-image"
	deploymentObjectType     = "deployment"
	imageObjectType          = "image"
	teamObjectType           = "team"
	userObjectType           = "user"
	auditObjectType          = "audit"
	boardModelObjectType     = "board-model"
	boardObjectType          = "board"
	testObjectType           = "test"

	// Errors messages
	initRPAPIInterfaceError   = "either logR pointer or httpCli pointer is nil"
	projectCreateNilError     = "the rpapiv1.RPProject pointer needs to be different than nil"
	imageCreateNilError       = "the rpapiv1.RPImage pointer needs to be different than nil"
	userCreateNilError        = "the rpapiv1.RPUser pointer needs to be different than nil"
	appCreateNilError         = "the rpapiv1.RPApplication pointer needs to be different than nil"
	appUploadNilError         = "the rpapiv1.RPFile pointer needs to be different than nil"
	teamCreateNilError        = "the rpapiv1.RPTeam pointer needs to be different than nil"
	teamInviteNilError        = "the rpapiv1.RPInvit pointer needs to be different than nil"
	memberAddNilError         = "the rpapiv1.RPMember pointer needs to be different than nil"
	prjReleaseNilError        = "the rpapiv1.RPTeamForRelease pointer needs to be different than nil"
	servicePostNilError       = "the map[string]interface{} pointer needs to be different than nil"
	rpBranchNilError          = "the rpapiv1.RPBranch pointer needs to be different than nil"
	rpBranchNameNilError      = "the rpapiv1.RPBranchName pointer needs to be different than nil"
	rpApplicationCopyNilError = "the rpapiv1.RPApplicationCopy pointer needs to be different than nil"
	accessTokenExpiredError   = "the access token of \"%s\" connection is expired, please generate a new one"
	status403ErrorOnObjError  = "403 HTTP status received from Redpesk backend. Either the %s does not exist or you are not allowed to access it."
	status503Error            = "'503 - service unavailable' - the backend server of your \"%s\" connection is not available - check with your administrator the stack is online and available"
	rpConfigError             = "[Redpesk config] %v"
)
