/**
 * Copyright (C) 2021-2023 IoT.bzh Company
 * Contact: https://www.iot.bzh/licensing
 *
 * This file is part of the redpesk-cli project, the redpesk command line tool.
 *
 * $RP_BEGIN_LICENSE$
 * Commercial License Usage
 *  Licensees holding valid commercial IoT.bzh licenses may use this file in
 *  accordance with the commercial license agreement provided with the
 *  Software or, alternatively, in accordance with the terms contained in
 *  a written agreement between you and The IoT.bzh Company. For licensing terms
 *  and conditions see https://www.iot.bzh/terms-conditions. For further
 *  information use the contact form at https://www.iot.bzh/contact.
 *
 * GNU General Public License Usage
 *  Alternatively, this file may be used under the terms of the GNU General
 *  Public license version 3. This license is as published by the Free Software
 *  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 *  of this file. Please review the following information to ensure the GNU
 *  General Public License requirements will be met
 *  https://www.gnu.org/licenses/gpl-3.0.html.
 * $RP_END_LICENSE$
 */

package ladapi

import (
	"errors"
)

// -------------------------------------------------------------------------------
// Types definition --------------------------------------------------------------
// -------------------------------------------------------------------------------

// RPLADExecCmdStruct structure used to request Redpesk LAD to run a command locally
type RPLADExecCmdStruct struct {
	RPLADMainCmdParams
	CmdLine string `json:"command_line"`
}

// -------------------------------------------------------------------------------
// -------------------------------------------------------------------------------

// ExecPost runs the specified command in the local builder
//
// :param cmd: Pointer to the RPLADExecCmdStruct structure containing the command
// :type cmd: *RPLADExecCmdStruct
// :param runnerTicket: Pointer to the RPLADRunnerTicket structure to fill with the answer
// :type runnerTicket: *RPLADRunnerTicket
// :returns: error -- an error if a problem has occurred
func (ladAPI *RPLADAPI) ExecPost(cmd *RPLADExecCmdStruct, runnerTicket *RPLADRunnerTicket) error {
	var tmpTicket *RPLADRunnerTicket

	// Check that the pointer to the structure to send is not nil
	if cmd == nil {
		return errors.New(execCmdNilError)
	}

	if runnerTicket == nil {
		tmpTicket = &RPLADRunnerTicket{}
	} else {
		tmpTicket = runnerTicket
	}

	// Logging purpose --------------------------
	ladAPI.Log.Infof("[iotpkg] working dir : %s", cmd.WorkingDir)
	ladAPI.Log.Infof("[iotpkg] command line: %s", cmd.CmdLine)
	// ------------------------------------------

	if err := ladAPI.HTTPCli.Post(execRoute, cmd, tmpTicket); err != nil {
		return err
	}

	return nil
}
