/**
 * Copyright (C) 2021-2023 IoT.bzh Company
 * Contact: https://www.iot.bzh/licensing
 *
 * This file is part of the redpesk-cli project, the redpesk command line tool.
 *
 * $RP_BEGIN_LICENSE$
 * Commercial License Usage
 *  Licensees holding valid commercial IoT.bzh licenses may use this file in
 *  accordance with the commercial license agreement provided with the
 *  Software or, alternatively, in accordance with the terms contained in
 *  a written agreement between you and The IoT.bzh Company. For licensing terms
 *  and conditions see https://www.iot.bzh/terms-conditions. For further
 *  information use the contact form at https://www.iot.bzh/contact.
 *
 * GNU General Public License Usage
 *  Alternatively, this file may be used under the terms of the GNU General
 *  Public license version 3. This license is as published by the Free Software
 *  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 *  of this file. Please review the following information to ensure the GNU
 *  General Public License requirements will be met
 *  https://www.gnu.org/licenses/gpl-3.0.html.
 * $RP_END_LICENSE$
 */

package ladapi

import (
	"errors"
)

// -------------------------------------------------------------------------------
// Types definition --------------------------------------------------------------
// -------------------------------------------------------------------------------

// RPLADWinResize represents the structure used to resize a window of a command
// currently running
type RPLADWinResize struct {
	RPLADWinSize
	ID string `json:"id"`
}

// RPLADSignalSend represents the structure used to send a signal to a remote process
// currently running
type RPLADSignalSend struct {
	ID     string `json:"id"`
	Signal string `json:"signal"`
}

// -------------------------------------------------------------------------------
// -------------------------------------------------------------------------------

// TerminalSizePut Resize the window currently used to run the identified
// command
//
// :param size: Pointer to the RPLADWinResize structure containing the new sizes
// :type size: *RPLADWinResize
// :returns: error -- an error if a problem has occurred
func (ladAPI *RPLADAPI) TerminalSizePut(size *RPLADWinResize) error {

	// Check that the pointer to the structure to send is not nil
	if size == nil {
		return errors.New(winSizeNilError)
	}

	if err := ladAPI.HTTPCli.Put(terminalSizeRoute, size, nil); err != nil {
		return err
	}

	return nil
}

// TerminalSendSignalPost send a signal to a remote process currently running
//
// :param size: Pointer to the RPLADWinResize structure containing the new sizes
// :type size: *RPLADWinResize
// :returns: error -- an error if a problem has occurred
func (ladAPI *RPLADAPI) TerminalSendSignalPost(signal *RPLADSignalSend) error {

	// Check that the pointer to the structure to send is not nil
	if signal == nil {
		return errors.New(procSignalNilError)
	}

	if err := ladAPI.HTTPCli.Post(terminalSignalRoute, signal, nil); err != nil {
		return err
	}

	return nil
}
