#!/usr/bin/env python3

# *****************************************
# Copyright (C) 2023-2024 IoT.bzh Company *
# *****************************************
# Contact: https://www.iot.bzh/licensing

# This file is part of the redtunamagic-ship module of the RedPesk project.

# $RP_BEGIN_LICENSE$
# Commercial License Usage
# Licensees holding valid commercial IoT.bzh licenses may use this file in \
# accordance with the commercial license agreement provided with the \
# Software or, alternatively, in accordance with the terms contained in \
# a written agreement between you and The IoT.bzh Company. For licensing terms \
# and conditions see https://www.iot.bzh/terms-conditions. For further \
# information use the contact form at https://www.iot.bzh/contact.

# GNU General Public License Usage
# Alternatively, this file may be used under the terms of the GNU General \
# Public license version 3. This license is as published by the Free Software \
# Foundation and appearing in the file LICENSE.GPLv3 included in the packaging \
# of this file. Please review the following information to ensure the GNU \
# General Public License requirements will be met \
# https://www.gnu.org/licenses/gpl-3.0.html.
# $RP_END_LICENSE$
# *****************************************

import sys

if __name__ == "__main__":
    
    # Get the file given as argument
    if len(sys.argv) < 2:
        sys.exit("Error: please provide the name of the input file as argument")
    input_file = sys.argv[1]

    # Now open the file and read its content
    with open(input_file) as f:
        cmd_tree_content = f.readlines()

    # First iteration over all the lines, goals:
    # 1/ Convert tabs to spaces
    # 2/ Find the maximum index of the usage ammong all the lines
    cmd_tree_content_spaces = []
    max_index = 0
    for line in cmd_tree_content:
        # Now, convert the tabs to 4 spaces
        tmp_line = line.expandtabs(4)
        # For the tmp_line get the maximum location of the beginning of the usage string '--'
        current_index = tmp_line.find("--")
        if current_index > max_index:
            max_index = current_index
        # Save the current line
        cmd_tree_content_spaces.append(tmp_line)

    # Second iteration over all the lines, goal:
    # 1/ Align all the usages to the max one
    cmd_tree_content_aligned = []
    for line in cmd_tree_content_spaces:
        # Split the line on '--'
        split_line = line.split("--")
        # Get the length of first part
        first_part_len = len(split_line[0])
        # Do padding on first item
        padded_first_part = split_line[0].ljust(max_index)
        # Add the joined part in our list
        cmd_tree_content_aligned.append('--'.join([padded_first_part, split_line[1]]))

    # Now write the file
    with open('cmd-tree-aligned.txt', 'w') as f:
        f.writelines(cmd_tree_content_aligned)

    # Exit cleanly
    sys.exit(0)



    